******************************************************************
** ProcFormat_asthma_2021.SAS                                    *
*                                                                *
* modified:		May 05, 2014, Rick Hu		                     *
* Last modified:	Jul 17, 2014, Rick Hu 		                 *
* Last modified:	Jan 16, 2015, EKelly                         *
*                  - copy over 2013 sas code into 2014 folder    *
*                  - ( Added in AGEG_F3_M )                      *
*                                                                *
*     EKelly Modified AGEG_F3_M to be 18-44, 45-64, 65+          *
*                                                                *
*     EKelly Dec 18, 2015   for Mult Yrs 2011-2013               *
*                                                                *
*     EKelly Feb 01, 2016   added in formats for:                *
*        Inhaler_ID_10	 Inhaler_ID_18	 Inhaler_ID_29           *
*        ILP03_10	     ILP03_18	     ILP03_29                *
*        ILP04_10	     ILP04_18	     ILP04_29                *
*        ILP05_10	     ILP05_18	     ILP05_29                *
*        ILP06_10	     ILP06_18	     ILP06_29                *
*        ILP08_10	     ILP08_18	     ILP08_29                *
*        ILP10_10	     ILP10_18	     ILP10_29                *
*                                                                *
*      EKelly Mar 14, 2016   added in formats for:               *
*        MOSTKNOW, PRESENTALT, KNOWMOST, ALTPRESENT              * 
*                                                                *   
*      EKelly Feb 2021   added in formats for:                   *
*       - COVID_19, COVID_ER, COVIDHSP, COORDIN                  *   
*       - increase NEB_ID series to 19                           * 
*       - increase Inhaler  series to 51                         *
*                                                                *
*      EKelly May 2021   added in formats for:                   *
*       - INH_LAMA                                               *   
*       - NEB_LAMA                                               * 
*                                                                *
*       - Also increased the range for                           *
*          INH_AI   to 4                                         *
*          INH_B2AL to 10                                        *
*          INH_CS   to 21                                        *
*****************************************************************;

%let Qdrive  = \\Cdc\project\CCHP_NCCD_DACH_BRFSS;
%let Multiple_year_CYYYY  = 2012_2014;
%let Multiple_year_CYYYY  = 2021;

 libname LIBRARY "&Qdrive\BRFSS\Projects\Asthmacell\&Multiple_year_CYYYY\library" ;
*libname LIBRARY "&Qdrive\BRFSS\Projects\Asthmacell\&Multiple_year_CYYYY\library\formats" ;

ods listing;
PROC PRINTTO; RUN ;

 Proc FORMAT LIBRARY = LIBRARY.LIBRARY;
 *Proc FORMAT LIBRARY = LIBRARY.LIBRAR2;
 *Proc FORMAT LIBRARY = LIBRARY.FORMATS;   *** SAS defaults to Formats Name not Library ***;

  Value  $BIRTHW1z
  "000001" - "003015" = "Pounds/Ounces "
  "777777" = "Don't know "
  "999999" = "Refused "
  " " = "Partial complete "
  ;
 
  Value  $HEIGHT1z
  "0001" - "0811" = "Feet/Inches "
  "7777" = "Don't know "
  "9999" = "Refused "
  " " = "Partial complete "
  ;
 
  Value  $IDAY
  "1" - "31" = "Interview day "
  ;

   Value  $IDAY_F
  "1" - "31" = "Interview day "
  ;
 
  Value  $IMONTH_F
  "1" = "January "
  "2" = "February "
  "3" = "March "
  "4" = "April "
  "5" = "May "
  "6" = "June "
  "7" = "July "
  "8" = "August "
  "9" = "September "
  "10" = "October "
  "11" = "November "
  "12" = "December "
  ;
 
  Value  $IYEAR
  "2006" = "Interview year "
  "2007" = "Interview year "
  "2008" = "Interview year "
  "2009" = "Interview year "
  "2010" = "Interview year "
  "2011" = "Interview year "
  "2012" = "Interview year "
  "2013" = "Interview year "
  "2014" = "Interview year "
  "2015" = "Interview year "
  "2016" = "Interview year "
  "2017" = "Interview year "
  "2018" = "Interview year "
  "2019" = "Interview year "
  "2020" = "Interview year "
  "2021" = "Interview year "
  "2022" = "Interview year "
  "2023" = "Interview year "
  "2024" = "Interview year "
  "2025" = "Interview year "
  ;

  Value  $IYEAR_F
  "2006" = "Interview year "
  "2007" = "Interview year "
  "2008" = "Interview year "
  "2009" = "Interview year "
  "2010" = "Interview year "
  "2011" = "Interview year "
  "2012" = "Interview year "
  "2013" = "Interview year "
  "2014" = "Interview year "
  "2015" = "Interview year "
  "2016" = "Interview year "
  "2017" = "Interview year "
  "2018" = "Interview year "
  "2019" = "Interview year "
  "2020" = "Interview year "
  "2021" = "Interview year "
  "2022" = "Interview year "
  "2023" = "Interview year "
  "2024" = "Interview year "
  "2025" = "Interview year "
  ;
 
  Value  $IYEAR_FX
  "2011" = "2011 Interview year "
  "2012" = "2012 Interview year "
  "2013" = "2013 Interview year "
  "2014" = "2014 Interview year "
  "2015" = "2015 Interview year "
  "2016" = "2016 Interview year "
  "2017" = "2017 Interview year "
  "2018" = "2018 Interview year "
  "2019" = "2019 Interview year "
  "2020" = "2020 Interview year "
  "2021" = "2021 Interview year "
  "2022" = "2022 Interview year "
  "2023" = "2023 Interview year "
  "2024" = "2024 Interview year "
  "2025" = "2025 Interview year "
  ;
      

  Value  $WEIGHT1z
  "0001" - "0500" = "Pounds "
  "7777" = "Don't know "
  "9999" = "Refused "
  " " = "Partial complete "
  ;
 
  Value  $WEIGHT2z
  "0001" - "0500" = "Pounds "
  "7777" = "Don't know "
  "9999" = "Refused "
  " " = "Partial complete "
  ;
 
  Value  ACTASTH
  1 = "Active Asthma "
  2 = "Inactive Asthma "
  9 = "Dont know/Not sure "
  . = "Not asked or missing "
  ;
 
  Value  ACT_DAYS30z
  1 = "Not at all "
  2 = "A little "
  3 = "A moderate amount "
  4 = "A lot "
  5 = "No current asthma, nothing happened past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  ACT_DAYS
  1 = "Not at all "
  2 = "A little "
  3 = "A moderate amount "
  4 = "A lot "
  5 = "No current asthma, nothing happened past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  ADLTCHLD_F
  1 = "Adult "
  2 = "Children "
  . = "Not asked or missing "
  ;
 

  Value  AGEDXA
  1 -115 = "Age in years "
  888 = "Less than 1 year old "
  777 = "Dont know "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  AGEDXC
  1 -17 = "Age in years "
  888 = "Less than 1 year old "
  777 = "Dont know "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  AGEG_F1z
  1 = "Age 18 - 99 "
  . = "Missing "
  ;

  Value  AGEG_F2z
  1 = "Age 18 - 44 "
  2 = "Age 45+ "
  . = "Missing "
  ;
 
  Value  AGEG_F3z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 54 "
  3 = "Age 55+ "
  . = "Missing "
  ;

  Value  AGEG_F3_M
  1 = "Age 18 - 44 "
  2 = "Age 45 - 64 "
  3 = "Age 65+ "
  . = "Missing "
  ;
 
  Value  AGEG_F4z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 45 - 54 "
  4 = "Age 55+ "
  . = "Missing "
  ;
 
  Value  AGEG_F4A
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 55 - 64 "
  4 = "Age 65+ "
  . = "Missing "
  ;

  Value  AGEG_F4_M
  1 = "Age 18 - 44 "
  2 = "Age 45 - 54 "
  3 = "Age 55 - 64 "
  4 = "Age 65+ "
  . = "Missing "
  ;
 
  Value  AGEG_F5z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 45 - 54 "
  4 = "Age 55 - 64 "
  5 = "Age 65+ "
  . = "Missing "
  ;
 
  Value  AGEG_F5_M
  1 = "Age 18 - 44 "
  2 = "Age 35 - 54 "
  3 = "Age 55 - 64 "
  4 = "Age 65 - 74 "
  5 = "Age 75+ "
  . = "Missing "
  ;
 
  Value  AGEG_F5_M2z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 54 "
  3 = "Age 55 - 64 "
  4 = "Age 65 - 74 "
  5 = "Age 75+ "
  . = "Missing "
  ;


  Value  AGEG_F5_M3z
  1 = "Age 18 - 24 "
  2 = "Age 25 - 34 "
  3 = "Age 35 - 44 "
  4 = "Age 55 - 64 "
  5 = "Age 65+ "
  . = "Missing "
  ;

  Value  AGEG_F5_M4z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 55 - 64 "
  4 = "Age 65 - 74 "
  5 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F5_M5z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 45 - 54 "
  4 = "Age 55 - 64 "
  5 = "Age 65+ "
  . = "Missing "
  ;

  Value  AGEG_F5_M6z
  1 = "Age 18 - 34 "
  2 = "Age 35 - 54 "
  3 = "Age 55 - 64 "
  4 = "Age 65 - 74 "
  5 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F6z
  1 = "Age 18 - 24 "
  2 = "Age 25 - 34 "
  3 = "Age 35 - 54 "
  4 = "Age 55 - 64 "
  5 = "Age 65 - 74 "
  6 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F6_M
  1 = "Age 18 - 34 "
  2 = "Age 35 - 44 "
  3 = "Age 45 - 54 "
  4 = "Age 55 - 64 "
  5 = "Age 65 - 74 "
  6 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F6_M2z
  1 = "Age 18 - 24 "
  2 = "Age 25 - 34 "
  3 = "Age 35 - 54 "
  4 = "Age 55 - 64 "
  5 = "Age 65 - 74 "
  6 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F6_M3z
  1 = "Age 18 - 24 "
  2 = "Age 25 - 34 "
  3 = "Age 35 - 44 "
  4 = "Age 55 - 64 "
  5 = "Age 65 - 74 "
  6 = "Age 75+ "
  . = "Missing "
  ;

  Value  AGEG_F7z
  1 = "Age 18 - 24 "
  2 = "Age 25 - 34 "
  3 = "Age 35 - 44 "
  4 = "Age 45 - 54 "
  5 = "Age 55 - 64 "
  6 = "Age 65 - 74 "
  7 = "Age 75+ "
  . = "Missing "
  ;

Value  AGEG_F11z
  1  = "Age 18 - 24 /Males"
  2  = "Age 25 - 44 /Males"
  3  = "Age 45 - 54 /Males"
  4  = "Age 55 - 64 /Males"
  5  = "Age 65+ /Males"
 
  6  = "Age 18 - 34 /Females"
  7  = "Age 35 - 44 /Females"
  8  = "Age 45 - 54 /Females"
  9  = "Age 55 - 64 /Females"
  10 = "Age 65 - 74 /Females"
  11 = "Age 75+ /Females"
  .  = "Missing "
  ;
 
  Value  AIRCLEANER
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  ASLEEP30z
  1 -30 = "Days/Nights "
  66 = "No symptoms past one year, skip filled "
  77 = "Don't know "
  88 = "None "
  99 = "Refused "
  100 = "Symptoms 3 months to 1 year ago, skip filled "
  111 = "No symptoms in the past 30 days, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  ASMDCOST
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  ASRXCOST
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  ASSPCOST
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  ASTHMA3z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  
  Value  BATH_FAN
  1 = "Yes "
  2 = "No or No Fan "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  BIRTHRF
  0 = "Partial complete "
  1 = "Yes "
  2 = "No "
  7 = "Don't know "
  9 = "Refused "
  . = "Have reported birth weight "
  ;
 
  Value  BRONCH
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAGEG_F1z
  1 = "Age 0 - 17 "
  . = "Missing "
  ;
 
  Value  CAGEG_F2z
  1 = "Age 0 - 9 "
  2 = "Age 10 - 17 "
  . = "Missing "
  ;
 
  Value  CAGEG_F3z
  1 = "Age 0 - 6   "
  2 = "Age 7 - 12  "
  3 = "age 13 - 17 "
  . = "Missing "
  ;
 
  Value  CAGEG_F3A
  1 = "0-6   Years old / Males"
  2 = "7-12  Years old / Males"
  3 = "13-17 Years old / Males"

  4 = "0-12  Years old / Females"
  5 = "13-17 Years old / Females"
  . = "Missing "
  ;

  Value  CAGEG_F3_M
  1 = "Age 0 - 9   "
  2 = "Age 10 - 14 "
  3 = "Age 15 - 17 "
  . = "Missing "
  ;

  Value  CAGEG_F4z
  1 = "Age 0 - 4 "
  2 = "Age 5 - 9 "
  3 = "Age 10 - 14 "
  4 = "Age 15 - 17 "
  . = "Missing "
  ;
 
   value CAGEG_F4A
   1 = '0~4   Years old / Males'
   2 = '5~9   Years old / Males'
   3 = '10~14 Years old / Males'
   4 = '15~17 Years old / Males'

   5 = '0~9   Years old / Females'
   6 = '10~14 Years old / Females'
   7 = '15~17 Years old / Females'
   . = "MISSING"
   ;

  Value  CALLBACK_F
  1 = "Yes "
  2 = "No "
  . = "Missing "
  ;

  
  Value  CALLBACK_VER
  1 = "Callback using  Protocol (2 weeks) "
  2 = 'Callback conducted "Immediately" '
  . = "Not asked or missing "
  ;
 
  Value  CAM_AROM
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_BR
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_HERB
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_HOME
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_NATR
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_OTHR
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_PRES
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_PUNC
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_REFL
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_VITA
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CAM_YOGA
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  CARPET
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  CASTHDX2z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  CASTHDX2_F
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  CASTHNO2z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  CASTHNO2_F
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  COMPASTH
  1 = "Shorter "
  2 = "Longer "
  3 = "About the same "
  4 = "The most recent attack was actually the first attack "
  6 = "No symptoms past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  11 = "No episode/asthma attack past year, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  COOK_GAS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  COPD
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;

  Value  COORDIN
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  COVID_19z
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
  
  Value  COVID_ER
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  COVIDHSP
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  CRACEG_F
  1 = "Races are collapsed to 1 group "
  . = "Missing "
  ;
 
  Value  CSTATE1_F
  1 = "Yes "
  2 = "No "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  CSTATE
  1 = "Yes "
  2 = "No "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  CSTATE1z
  1 = "Yes "
  2 = "No "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;

  Value  CUR_ASTH
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  C_ROACH
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  C_RODENT
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  DAYCARE
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DAYCARE1z
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  5 = "Goes to daycare now, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DCARE_ANML
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  5 = "No daycare past year, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DCARE_APL
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  4 = "No current asthma, skip filled "
  5 = "No daycare past year, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DCARE_MLD
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  5 = "No daycare past year, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DCARE_SMK
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  5 = "No daycare past year, skip filled "
  6 = "Over age ten, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DEHUMID
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  DEPRESS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  DISPCODE_F
  1100 = "Complete "
  1200 = "Partial complete "
  ;
 
  Value  DUR_30D
  1 = "Yes "
  2 = "No "
  6 = "Last symptoms one+ years ago, skip filled "
  7 = "Don't know "
  9 = "Refused "
  10 = "Last symptoms 3 months - 1 year ago, skip filled "
  11 = "No symptoms 'SYMP_30D' skip filled "
  12 = "1-29 'SYMP_30D' skip filled "
  77 = "Don't know 'SYMP_30D' skip filled "
  99 = "Refused 'SYMP_30D' skip filled "
  . = "Not asked or missing "
  ;
 
  Value  DUR_ASTH
  101 -199 = "Minutes "
  201 -299 = "Hours "
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "No symptoms past 1 year, skip filled "
  777 = "Don't know "
  999 = "Refused "
  1111 = "No episode/asthma attack past year, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  EMPHY
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  EMP_EVER1z
  1 = "Yes "
  2 = "No "
  6 = "Now Employed, skip filled "
  7 = "Dont know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  EMP_STAT
  1 = "Employed full-time "
  2 = "Employed part-time "
  3 = "Not employed "
  7 = "Dont know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  END_OF_FILE
  1 = "Yes "
  . = "Not asked or missing "
  ;
 
  Value  ENV_MOLD
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  ENV_PETS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  EPIS_12M
  1 = "Yes "
  2 = "No "
  6 = "No symptoms past 1 year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  EPIS_TP
  1 -100 = "Episodes "
  666 = "No symptoms past 1 year, skip filled "
  777 = "Don't know "
  888 = "None "
  999 = "Refused "
  1111 = "No episode/asthma attack past year, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  ER_TIMES
  1 -365 = "Number "
  555 = "No current asthma, nothing happened past year, skip filled "
  666 = "No MD visit past year, skip filled "
  677 = "MD visit, no ER visit past year, skip filled "
  777 = "Don't know "
  888 = "None "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  ER_VISIT
  1 = "Yes "
  2 = "No "
  5 = "No current asthma, nothing happened past year, skip filled "
  6 = "No MD visit past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  EVER_ASTH
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  E_PILLOW
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  FLAG1z
  0 = "AGE, AGEDX, and INCIDNT are consistent "
  1 = "AGEDX is greater than AGE "
  2 = "AGE, AGEDX, and INCIDNT are inconsistent "
  . = "Skip filled "
  ;
 
  Value  FLU_SHOT
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  FLU_SPRAY
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  FMONTH_F
  1 = "January "
  2 = "February "
  3 = "March "
  4 = "April "
  5 = "May "
  6 = "June "
  7 = "July "
  8 = "August "
  9 = "September "
  10 = "October "
  11 = "November "
  12 = "December "
  ;
 
  Value  GAS_STOVE
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  GUARDIAN
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  HOSPPLAN
  1 = "Yes "
  2 = "No "
  4 = "MD visit, no symptoms past year, skip filled "
  5 = "No current asthma, nothing happened past year, skip filled "
  6 = "No MD visit past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  45 = "MD visit, symptoms, no hospital visit past year, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  HOSPTIME
  1 -365 = "Times "
  444 = "MD visit, no symptoms past year, skip filled "
  455 = "MD visit, symptoms, no hospital visit past year, skip filled "
  555 = "No current asthma, nothing happened past year, skip filled "
  666 = "No MD visit past year, skip filled "
  777 = "Don't know "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  HOSP_VST
  1 = "Yes "
  2 = "No "
  4 = "MD visit, no symptoms past year, skip filled "
  5 = "No current asthma, nothing happened past year, skip filled "
  6 = "No MD visit past year, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  HOTWATER
  1 = "Cold "
  2 = "Warm "
  3 = "Hot "
  4 = "Varies "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  ILP03_1z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_43z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP03_10z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP03_11z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_12z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_13z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_14z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_15z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_16z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_17z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_18z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP03_44z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value ILP03_45z
  	1	=	"Yes"
 	2	=	"No"
	3	=	"Medication is a dry powder inhaler or disk inhaler, not a canister inhaler"
	4	=	"Medication has a built-in spacer/does not need a spacer"
	7	=	"Dont know"
	9	=	"Refused"
    . 	=   "Skip filled"
   ;

    Value  ILP03_46z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value ILP03_47z
  	1	=	"Yes"
 	2	=	"No"
	3	=	"Medication is a dry powder inhaler or disk inhaler, not a canister inhaler"
	4	=	"Medication has a built-in spacer/does not need a spacer"
	7	=	"Dont know"
	9	=	"Refused"
    . 	=   "Skip filled"
   ;

    Value  ILP03_48z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value ILP03_49z
  	1	=	"Yes"
 	2	=	"No"
	3	=	"Medication is a dry powder inhaler or disk inhaler, not a canister inhaler"
	4	=	"Medication has a built-in spacer/does not need a spacer"
	7	=	"Dont know"
	9	=	"Refused"
    . 	=   "Skip filled"
   ;

    Value  ILP03_50z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value ILP03_51z
  	1	=	"Yes"
 	2	=	"No"
	3	=	"Medication is a dry powder inhaler or disk inhaler, not a canister inhaler"
	4	=	"Medication has a built-in spacer/does not need a spacer"
	7	=	"Dont know"
	9	=	"Refused"
    . 	=   "Skip filled"
   ;


  Value  ILP03_19z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_2z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_20z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_21z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_22z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_23z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_24z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_25z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_26z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_27z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_28z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP03_29z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_3z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_30z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_31z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_32z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_33z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_34z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_35z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_36z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_37z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_38z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_39z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_4z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_40z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_41z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_42z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_5z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_6z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_7z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_8z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP03_9z
  1 = "Yes "
  2 = "No "
  3 = "Medication is a dry powder inhaler or disk inhaler, not a canister inhaler "
  4 = "Medication has a built-in spacer/does not need a spacer "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_1z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_43z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP04_10z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP04_11z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_12z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_13z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_14z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_15z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_16z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_17z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_44z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP04_45z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP04_46z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP04_47z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP04_48z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP04_49z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP04_50z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

 Value  ILP04_51z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;


  Value  ILP04_18z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_19z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_2z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_20z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_21z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_22z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_23z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_24z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_25z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_26z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_27z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_28z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_29z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_3z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_30z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_31z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_32z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_33z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_34z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_35z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_36z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_37z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_38z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_39z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_4z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_40z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_41z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_42z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_5z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_6z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_7z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_8z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP04_9z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_1z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_43z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_10z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP05_11z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_12z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_13z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_14z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_15z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_16z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_17z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_44z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_45z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_46z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_47z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_48z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_49z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_50z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_51z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_18z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_19z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_2z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_20z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_21z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_22z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_23z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_24z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_25z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_26z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_27z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_28z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_29z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_3z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_30z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_31z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_32z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_33z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_34z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_35z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_36z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_37z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_38z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_39z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_4z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_40z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_41z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_42z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_5z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_6z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_7z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_8z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP05_9z
  1 = "Yes "
  2 = "No "
  3 = "Didnt exercise in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_1z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_43z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_10z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_11z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_12z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_13z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_14z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_15z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_16z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_17z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_18z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_44z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_45z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_46z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_47z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_48z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_49z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_50z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_51z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_19z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_2z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_20z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_21z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_22z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_23z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_24z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_25z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_26z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_27z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_28z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_29z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP06_3z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_30z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_31z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_32z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_33z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_34z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_35z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_36z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_37z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_38z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_39z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_4z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_40z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_41z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_42z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_5z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_6z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_7z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_8z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP06_9z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_1z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_43z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_10z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_11z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_12z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_13z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_14z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_15z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_16z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_17z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_18z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ; 

  Value  ILP08_44z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_45z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_46z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_47z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_48z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_49z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_50z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP08_51z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;


  Value  ILP08_19z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_2z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_20z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_21z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_22z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_23z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_24z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_25z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_26z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_27z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_28z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_29z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_3z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_30z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_31z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_32z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_33z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_34z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_35z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_36z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_37z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_38z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_39z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_4z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_40z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_41z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_42z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_5z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_6z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_7z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_8z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP08_9z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_1z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_43z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_10z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP10_11z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_12z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_13z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_14z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_15z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_16z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_17z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_44z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_45z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_46z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_47z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_48z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_49z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_50z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
    
  Value  ILP10_51z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_18z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_19z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_2z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_20z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_21z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_22z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_23z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_24z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_25z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_26z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_27z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_28z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_29z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;

  Value  ILP10_3z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_30z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_31z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_32z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_33z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_34z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_35z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_36z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_37z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_38z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_39z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_4z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_40z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_41z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_42z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_5z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_6z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_7z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_8z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  ILP10_9z
  1 -76 = "01-76 canisters "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Skip filled "
  ;
 
  Value  INCIDNT
  1 = "Within the past 12 months "
  2 = "One to five years ago "
  3 = "More than 5 years ago "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INHALERE
  1 = "Yes "
  2 = "No "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INHALERH
  1 = "Yes "
  2 = "No "
  5 = "Never took asthma medication, skip filled "
  6 = "Never used prescription inhaler, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INHALERW
  1 = "Yes "
  2 = "No "
  5 = "Never took asthma medication, skip filled "
  6 = "Never used prescription inhaler, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_1z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_43z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_10z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_11z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_12z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_13z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_14z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_15z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_16z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_17z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_44z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_45z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

 Value  INHALER_ID_46z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_47z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_48z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_49z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_50z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_51z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

  Value  INHALER_ID_18z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_19z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_2z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_20z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_21z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_22z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_23z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_24z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_25z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_26z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_27z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_28z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_29z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_3z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_30z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_31z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_32z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_33z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_34z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_35z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_36z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_37z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_38z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_39z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_4z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_40z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_41z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_42z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_5z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_6z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_7z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_7799z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_8z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_ID_9z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  INHALER_TEXT1z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT2z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT3z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT4z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT5z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT6z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT7z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT8z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INHALER_TEXT96z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  INH_AC
  0 -3 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  INH_AI
  0 -4 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  INH_B2AL
  0 -10 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  INH_B2AS
  0 -14 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  INH_CS
  0 -21 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  INH_LAMA
  0 - 7 = "Count "
  99    = "Missing "
  .     = "Skip filled "
  ;

  Value  INH_SCR
  1 = "Yes, inhaler in past 3 months "
  2 = "No inhaler in past 3 months "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  6 = "Asthma med. past 3 months, never used inhaler, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INS1z
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INS2z
  1 = "Yes "
  2 = "No "
  5 = "No insurance at time of interview, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  INS_TYP
  1 = "Parents employer "
  2 = "Medicaid/Medicare "
  3 = "CHIP {replace with state specific  name} "
  4 = "Other "
  5 = "No insurance at time of interview, skip filled "
  7 = "Dont know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  KITC_FAN
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  LASTSYMP
  88 = "Never "
  1 = "Less than 1 day ago "
  2 = "1-6 days ago "
  3 = "1 week to less than 3 months ago "
  4 = "3 months to less than 1 year ago "
  5 = "1 year to less than 3 years ago "
  6 = "3 years to 5 years ago "
  7 = "More than 5 years ago "
  77 = "Dont know "
  99 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  LAST_MD
  88 = "Never "
  4 = "Within the past year "
  5 = "One year to less than 3 years ago "
  6 = "Three years to five years ago "
  7 = "More than five years ago "
  77 = "Dont know "
  99 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  LAST_MED
  88 = "Never "
  1 = "Less than 1 day ago "
  2 = "1-6 days ago "
  3 = "1 week to less than 3 months ago "
  4 = "3 months to less than 1 year ago "
  5 = "1 year to less than 3 years ago "
  6 = "3 years to 5 years ago "
  7 = "More than 5 years ago "
  77 = "Dont know "
  99 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  MATTRESS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  MGT_CLAS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  MGT_PLAN
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  MISS_DAY
  1 -365 = "Days "
  555 = "No current asthma, nothing happened past year, skip filled "
  777 = "Don't know "
  888 = "Zero "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  MISS_DCAR
  1 -365 = "Days "
  444 = "No current asthma, skip filled "
  555 = "No daycare past year, skip filled "
  666 = "Over age ten, skip filled "
  777 = "Don't know "
  888 = "Zero "
  999 = "Refused "
  3333 = "Home school, skip filled "
  . = "Partial complete "
  ;
 
  Value  MISS_SCHL
  1 -365 = "Days "
  444 = "No school past year, skip filled "
  555 = "Not old enough for school, skip filled "
  666 = "No current asthma, skip filled "
  777 = "Don't know "
  888 = "None "
  999 = "Refused "
  . = "Partial complete "
  ;
 
  Value  MKP_NAME
  1 = "Yes "
  2 = "No "
  ;
 
  Value  MKP_PERS
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
/* turn on for 2011-2013 project
  Value  MKP_STATUS
  1 = "BRFSS respondent is the MKP and will continue "
  2 = "Alternate respondent is the MKP and will continue "
  . = "Not asked or missing "
  ;
*/
 
  Value  MKP_STATUS
  1 = "BRFSS respondent is the MKP and will continue "
  2 = "Alternate respondent is the MKP and will continue "
  . = "Not asked or missing "
  ;

  Value  MOD_ENV
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  NATTMPTS_F
  1 -15 = "Number of attempts of asthma call-back "
  ;
 
  Value  NEB01_1z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_10z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_11z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_12z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_13z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_14z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_15z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_16z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_17z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_18z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  NEB01_19z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_2z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_3z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_4z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_5z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_6z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_7z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_8z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB01_9z
  1 = "Yes "
  2 = "No "
  3 = "No attack in past 3 months "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_1z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_10z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_11z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_12z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_13z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_14z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_15z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_16z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_17z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_18z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  NEB02_19z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;

  Value  NEB02_2z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_3z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_4z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_5z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_6z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_7z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_8z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB02_9z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_1z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_10z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_11z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_12z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_13z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_14z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_15z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_16z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_17z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  NEB03_18z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;

  Value  NEB03_19z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_2z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_3z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_4z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_5z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_6z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_7z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_8z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB03_9z
  301 -399 = "Days "
  401 -499 = "Weeks "
  555 = "Never "
  666 = "Less often than once a  week "
  777 = "Dont know/Not sure "
  999 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_AC
  0 -4 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  NEB_CS
  0 -2 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  NEB_AI
  0 -2 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  NEB_B2A
  0 -11 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  NEB_B2AL
  0 -1 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  NEB_LAMA
  0 -1  = "Count "
  99    = "Missing "
  .     = "Skip filled "
  ;

  Value  NEB_ID_1z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_10z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_11z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_12z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_13z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_14z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_15z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_16z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_17z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_18z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_19z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_2z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_3z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_4z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_5z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_6z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_7z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_7799z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_8z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_ID_9z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  NEB_PLCA
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Dont know "
  8 = "No neb. in past 3 months, skip filled "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_PLCB
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Dont know "
  8 = "No neb. in past 3 months, skip filled "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_PLCC
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Dont know "
  8 = "No neb. in past 3 months, skip filled "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_PLCD
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Dont know "
  8 = "No neb. in past 3 months, skip filled "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_PLCE
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Dont know "
  8 = "No neb. in past 3 months, skip filled "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  NEB_SCR
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  NEB_TEXT1z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT2z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT3z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT4z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT5z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT6z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT7z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT8z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NEB_TEXT96z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  NER_TIME
  1 -365 = "Times "
  555 = "No current asthma, nothing happened past year, skip filled "
  666 = "No MD visit past year, skip filled "
  777 = "Don't know "
  888 = "None "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  NO_SCHL
  1 = "Not old enough "
  2 = "Home schooled "
  3 = "Unable to attend for health  reason "
  4 = "On vacation or break "
  5 = "Other "
  6 = "Now goes to outside school, skip filled "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  OTC
  1 = "Yes "
  2 = "No "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  OTHER_INHALER
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  OTHER_NEB
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  OTHER_PILLS
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  OTHER_SYRUP
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  O_STATE
  1 -100 = "2 digit state FIPSCODE "
  . = "Not asked or missing "
  ;
 
  Value  PERMISS
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  PETBEDRM
  1 = "Yes "
  2 = "No "
  3 = "Some are/some aren't "
  6 = "No pets, skip coded "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  PILL01_1z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_11z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_12z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_13z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_14z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_15z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_17z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_18z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_19z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_2z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_21z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_23z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_24z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_25z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_26z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_28z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_3z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_30z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_31z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_32z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_33z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_35z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_37z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_4z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_40z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_42z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_43z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_44z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_45z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_46z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_47z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_48z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_49z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_50z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_51z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_5z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_7z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILL01_8z
  1 = "Yes "
  2 = "No "
  7 = "Dont know "
  9 = "Refused "
  . = "Skip filled "
  ;
 
  Value  PILLS
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_1z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_11z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_12z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_13z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_14z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_15z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_17z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_18z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_19z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_2z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_21z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_23z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_24z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_25z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_26z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_28z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_3z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_30z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_31z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_32z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_33z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_35z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_37z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_4z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_40z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_42z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_43z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_44z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_45z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_46z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_47z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_48z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_49z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_50z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;

 Value  PILLS_ID_51z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_5z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_7z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_7799z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_ID_8z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  PILLS_TEXT1z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT2z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT3z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT4z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT5z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT6z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT7z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT8z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILLS_TEXT96z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  PILL_CS
  0 -6 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  PILL_LM
  0 -6 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  PILL_B2A
  0 -9 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  PILL_METH
  0 -15 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;

  Value  QSTVER
  10 = "10"
  11 = "11"
  12 = "12"
  13 = "13"
  20 = "20"
  21 = "21"
  22 = "22"
  23 = "23"
   ;
 
  Value  QSTVER_F
  10 = "Landline (No additional version) "
  11 = "Landline (One additional version) "
  12 = "Landline (Two additional versions) "
  13 = "Landline (Three additional versions) "
  20 = "Cell Phone (No additional version) "
  21 = "Cell Phone (One additional version) "
  22 = "Cell Phone (Two additional versions) "
  23 = "Cell Phone (Three additional versions) "
  .  = "Missing"
  ;

  Value  RACEG_F
  1 = "Races are collapsed to 1 group "
  . = "Missing "
  ;
 
  Value  REGION_F
  1 = "Regions are collapsed to 1 region "
  . = "No region collapsed "
  ;
 
  Value  RELATED
  1 = "Parents "
  2 = "Guardian "
  3 = "Other relative "
  4 = "Unrelated "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  RELATION
  1 = "Mother (Birth/Adoptive/Step) "
  2 = "Father (Birth/Adoptive/Step) "
  3 = "Brother/Sister (Step/Foster/Half/Adoptive) "
  4 = "Grandparent (Father/Mother) "
  5 = "Other relative "
  6 = "Unrelated "
  7 = "Dont know/Not sure "
  . = "Not asked or missing "
  ;
 
  Value  REPEAT
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  RSPSTAT1_F
  1 -100 = "2 digit state FIPSCODE "
  . = "Not asked or missing "
  ;
 
  Value  RSPSTATE
  1 -100 = "2 digit state FIPSCODE "
  . = "Not asked or missing "
  ;

  Value  RSPSTAT1z
  1 -100 = "2 digit state FIPSCODE "
  . = "Not asked or missing "
  ;

  Value  SAMP_NAME
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SAMP_PERS
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SCHGRADE
  1 -12 = "Grade "
  44 = "No school past year, skip filled "
  55 = "Not old enough for school, skip filled "
  66 = "Kindergarten "
  77 = "Don't know "
  88 = "Preschool "
  99 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCHL_12z
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  5 = "Not old enough for school, skip filled "
  6 = "Now goes to outside school, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCH_ANML
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  4 = "No school past year, skip filled "
  5 = "Not old enough for school, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCH_APL
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  4 = "No school past year, skip filled "
  5 = "Not old enough for school, skip filled "
  6 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCH_MED
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  4 = "No school past year, skip filled "
  5 = "Not old enough for school, skip filled "
  6 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCH_MOLD
  1 = "Yes "
  2 = "No "
  3 = "Home school, skip filled "
  4 = "No school past year, skip filled "
  5 = "Not old enough for school, skip filled "
  6 = "No current asthma, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCH_STAT
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  SCR_MED1z
  1 = "Yes "
  2 = "No "
  3 = "Respondent knows the meds "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  SCR_MED3z
  1 = "Yes, I have all the medications "
  2 = "Yes, I have some of the medications but not all "
  3 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  10 = "Know or no handy asthma medicines, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  SYMPFREE
  1 -14 = "Days/Nights "
  88 = "None "
  77 = "Dont know "
  99 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  SYMP_30D
  1 -29 = "Days "
  30 = "Every day "
  66 = "No symptoms past one year, skip filled "
  77 = "Don't know "
  88 = "No symptoms in the past 30 days "
  99 = "Refused "
  100 = "Symptoms 3 months to 1 year ago, skip filled "
  . = "Not asked or missing "
  ;
 
  Value  SYRP_B2AS
  0 -5 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  SYRP_CS
  0 -2 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  SYRP_METH
  0 -3 = "Count "
  99 = "Missing "
  . = "Skip filled "
  ;
 
  Value  SYRUP
  1 = "Yes "
  2 = "No "
  4 = "No asthma med. past 3 months, skip filled "
  5 = "Never took asthma medication, skip filled "
  7 = "Don't know "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_1z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_10z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_2z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_3z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_4z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_5z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_6z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_7z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_7799z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_8z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_ID_9z
  1 = "Yes "
  2 = "No "
  . = "Not asked or missing "
  ;
 
  Value  SYRUP_TEXT1z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT2z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT3z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT4z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT5z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT6z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT7z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT8z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  SYRUP_TEXT96z
  1 = "Yes "
  2 = "No "
  3 = "No other medication text filled "
  . = "Skip filled "
  ;
 
  Value  S_INSIDE
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  TCH_MON
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  TCH_RESP
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  TCH_SIGN
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  UNEMP_R
  1 = "Keeping house "
  2 = "Going to school "
  3 = "Retired "
  4 = "Disabled "
  5 = "Unable to work for other health reasons "
  6 = "Looking for work "
  7 = "Laid off "
  8 = "Other "
  66 = "Now Employed, skip filled "
  77 = "Don't know "
  88 = "Unknown Employment, skip filled "
  99 = "Refused "
  . = "Partial complete "
  ;
 
  Value  URG_TIME
  1 -365 = "Number "
  555 = "No current asthma, nothing happened past year, skip filled "
  666 = "No MD visit past year, skip filled "
  777 = "Don't know "
  888 = "None "
  999 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  WOOD_STOVE
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  WORKENV5z
  1 = "Yes "
  2 = "No "
  5 = "Now employed former/inactive/unknown asthma, skip filled "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  10 = "Previously but not currently employed, skip filled "
  . = "Partial complete "
  ;
 
  Value  WORKENV6z
  1 = "Yes "
  2 = "No "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  10 = "Previously but not currently employed, skip filled "
  . = "Partial complete "
  ;
 
  Value  WORKENV7z
  1 = "Yes "
  2 = "No "
  5 = "Caused by current job, skip filled "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  WORKENV8z
  1 = "Yes "
  2 = "No "
  5 = "Caused by current job, skip filled "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  WORKQUIT1z
  1 = "Yes "
  2 = "No "
  5 = "Caused by current job, skip filled "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  55 = "Not made worse or caused in any previous job, skip filled "
  . = "Partial complete "
  ;
 
  Value  WORKSEN3z
  1 = "Yes "
  2 = "No "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  WORKSEN4z
  1 = "Yes "
  2 = "No "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  WORKTALK
  1 = "Yes "
  2 = "No "
  6 = "Never employed, skip filled "
  7 = "Don't know "
  8 = "Past employment unknown, skip filled "
  9 = "Refused "
  . = "Partial complete "
  ;
 
  Value  _CUR_ASTH_C
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
 
  Value  _EVER_ASTH_C
  1 = "Yes "
  2 = "No "
  7 = "Dont know/Not sure "
  9 = "Refused "
  . = "Not asked or missing "
  ;
  

  value $INDI_LLCP	
    '1'	= "2012,2013,2014 landline and cell phone"
    '2'	= "2012,2013,2014 landline only"
    '3'	= "2012,2013 2014 landline, 2014 cell phone"
    '4'	= "2012,2013,2014 landline, 2013,2014 cell phone"
    ' ' = "Missing"
  ;

  value INDI_LLCPz	
    1 = "2012,2013,2014 landline and cell phone"
    2 = "2012,2013,2014 landline only"
    3 = "2012,2013 2014 landline, 2014 cell phone"
    4 = "2012,2013,2014 landline, 2013,2014 cell phone"
    . = "Missing"
  ;

  Value  SURVEYRz
      2006 = "BRFSS Asthma Call_Back survey year" 
      2007 = "BRFSS Asthma Call_Back survey year" 
      2008 = "BRFSS Asthma Call_Back survey year" 
      2009 = "BRFSS Asthma Call_Back survey year" 
      2010 = "BRFSS Asthma Call_Back survey year" 
      2011 = "BRFSS Asthma Call_Back survey year" 
      2012 = "BRFSS Asthma Call_Back survey year" 
      2013 = "BRFSS Asthma Call_Back survey year" 
      2014 = "BRFSS Asthma Call_Back survey year" 
      2015 = "BRFSS Asthma Call_Back survey year"
	  2016 = "BRFSS Asthma Call_Back survey year" 
      2017 = "BRFSS Asthma Call_Back survey year" 
      2018 = "BRFSS Asthma Call_Back survey year" 
      2019 = "BRFSS Asthma Call_Back survey year"
      .    = "Missing" 
   ; 
				
  value _CSEXG_z
          1	=	"MALE"
          2	=	"FEMALE"
          . =	"Missing"
   ;

  value _CRACEG_z
     1 = "White only"
     2 = "Black or African American only"
     3 = "Other races and Multiracial"
     . = "Missing"
  ;

   value  CHILD_RACE_M_YEARSz
	   1  = "White Respondents who reported their race as white."
       2  = "Black or African American Respondents who reported their race as black."
       3  = "American Indian or Alaskan Native Respondents who reported their race as American Indian or Alaska Native."
       4  = "Asian Respondents who reported their race as Asian."
       5  = "Native Hawaiian or other Pacific Islander Respondents who reported their race as Native Hawaiian or Pacific Islander."
       6  = "Other race Respondents who report they are of some other race group not listed in the question responses."
       7  = "No preferred race Respondents who reported they are of more than one race group but did not report a preference or the preferred race is missing"
       8  = "Multiracial but preferred race not answered Respondents who reported they are of more than one race group but did not answer the question about which race best represents them NOTE: This is a data collection error."
       77 =	"Dont know/Not sure Respondents who reported they didnt know their race and did not answer the question about which race best represents them."
       99 =	"Refused Respondents who refused to give their race and did not answer the question about which race best represents them."
       .  =	"Missing"
    ;

   value KNOWMOST
        1 = "Yes "
		2 = "No "
		7 = "Dont know/Not sure "
		9 = "Refused "
		. =	"Missing"
		;

	value PRESENTALT
		1 = "Yes "
		2 = "No "
		7 = "Dont know/Not sure "
		9 = "Refused "
		. =	"Missing"
		;

	value MOSTKNOW
		1 = "Yes "
		2 = "No "
		7 = "Dont know/Not sure "
		9 = "Refused "
		. =	"Missing"
		;

	value ALTPRESENT
		1 = "Yes "
		2 = "No "
		7 = "Dont know/Not sure "
		9 = "Refused "
		. =	"Missing"
		;


	 /***** from BRFSS Side ******/

 VALUE AD1DOWN                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never"                                                                                                                                                        
           2                   =    "For several days"                                                                                                                                             
           3                   =    "For more than half the days"                                                                                                                                  
           4                   =    "Nearly every day"                                                                                                                                             
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE AD1PLEAS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never"                                                                                                                                                        
           2                   =    "For several days"                                                                                                                                             
           3                   =    "For more than half the days"                                                                                                                                  
           4                   =    "Nearly every day"                                                                                                                                             
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE AD2DEPEV                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE ADLTCHLD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0                   =    "No selection"                                                                                                                                                 
           1                   =    "Adult"                                                                                                                                                        
           2                   =    "Child"                                                                                                                                                        
           ;                                                                                                                                                                                       
     VALUE ADSLEEP                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 14        =    "01-14 days"                                                                                                                                                   
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE AGE                                                                                                                                                                                     
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           18      - 24        =    "Age 18 - 24"                                                                                                                                                  
           25      - 34        =    "Age 25 - 34"                                                                                                                                                  
           35      - 44        =    "Age 35 - 44"                                                                                                                                                  
           45      - 54        =    "Age 45 - 54"                                                                                                                                                  
           55      - 64        =    "Age 55 - 64"                                                                                                                                                  
           65      - 99        =    "Age 65 or older"                                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE ALC5DAY                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           101     - 107       =    "Days per week"                                                                                                                                                
           201     - 230       =    "Days in past 30 days"                                                                                                                                         
           777                 =    "Dont know/Not sure"                                                                                                                                          
           888                 =    "No drinks in past 30 days"                                                                                                                                    
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE AST3HMA                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE ASTHNOW                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE AVE2DRNK                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of drinks"                                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           78      - 98        =    "Number of drinks"                                                                                                                                             
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE BLDSTOOL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE BLDSUGAR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           101     - 199       =    "Times per day"                                                                                                                                                
           201     - 299       =    "Times per week"                                                                                                                                               
           301     - 399       =    "Times per month"                                                                                                                                              
           401     - 499       =    "Times per year"                                                                                                                                               
           777                 =    "Dont know/Not sure"                                                                                                                                          
           888                 =    "Never"                                                                                                                                                        
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE BLIND                                                                                                                                                                                   
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE C1STATE                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CADULT                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, Male Respondent"                                                                                                                                         
           2                   =    "Yes, Female Respondent"                                                                                                                                       
           3                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CALLBACK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CALLBCKZ                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CARE1GIV                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           8                   =    "Caregiving recipient died in past 30 days"                                                                                                                    
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CARERCVD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Very satisfied"                                                                                                                                               
           2                   =    "Somewhat satisfied"                                                                                                                                           
           3                   =    "Not at all satisfied"                                                                                                                                         
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           8                   =    "Not applicable"                                                                                                                                               
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CASTH2DX                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CASTH2NO                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CCLGHOUS                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CDASSIST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Usually"                                                                                                                                                      
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Rarely"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CDDISCUS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CDHELP                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Usually"                                                                                                                                                      
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Rarely"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CDHOUSE                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Usually"                                                                                                                                                      
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Rarely"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CDSOCIAL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Usually"                                                                                                                                                      
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Rarely"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CELL4FON                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Not a cell phone"                                                                                                                                             
           2                   =    "Yes"                                                                                                                                                          
           ;                                                                                                                                                                                       
     VALUE CELL5FON                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CHC1COPD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know / Not sure"                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHC1KDNY                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know / Not sure"                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHCOCNCR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know / Not sure"                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHCSCNCR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know / Not sure"                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHECK1UP                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within past year (anytime less than 12 months ago)"                                                                                                           
           2                   =    "Within past 2 years (1 year but less than 2 years ago)"                                                                                                       
           3                   =    "Within past 5 years (2 years but less than 5 years ago)"                                                                                                      
           4                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "Never"                                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHILDAGE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0       - 11        =    "0 Years old"                                                                                                                                                  
           12      - 23        =    "1 Year old"                                                                                                                                                   
           24      - 35        =    "2 Years old"                                                                                                                                                  
           36      - 47        =    "3 Years old"                                                                                                                                                  
           48      - 59        =    "4 Years old"                                                                                                                                                  
           60      - 71        =    "5 Years old"                                                                                                                                                  
           72      - 83        =    "6 Years old"                                                                                                                                                  
           84      - 95        =    "7 Years old"                                                                                                                                                  
           96      - 107       =    "8 Years old"                                                                                                                                                  
           108     - 119       =    "9 Years old"                                                                                                                                                  
           120     - 131       =    "10 Years old"                                                                                                                                                 
           132     - 143       =    "11 Years old"                                                                                                                                                 
           144     - 155       =    "12 Years old"                                                                                                                                                 
           156     - 167       =    "13 Years old"                                                                                                                                                 
           168     - 179       =    "14 Years old"                                                                                                                                                 
           180     - 191       =    "15 Years old"                                                                                                                                                 
           192     - 203       =    "16 Years old"                                                                                                                                                 
           204     - 215       =    "17 Years old"                                                                                                                                                 
           777                 =    "Dont know / Not sure"                                                                                                                                        
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHILDREN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 87        =    "Number of children"                                                                                                                                           
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CHK3HEMO                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times  [76=76 or more]"                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           98                  =    "Never heard of A one C test"                                                                                                                                
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CIMEMLOS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CNCR1TYP                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Breast cancer"                                                                                                                                                
           2                   =    "Cervical cancer (cancer of the cervix)"                                                                                                                       
           3                   =    "Endometrial cancer (cancer of the uterus)"                                                                                                                    
           4                   =    "Ovarian cancer (cancer of the ovary)"                                                                                                                         
           5                   =    "Head and neck cancer"                                                                                                                                         
           6                   =    "Oral cancer"                                                                                                                                                  
           7                   =    "Pharyngeal (throat) cancer"                                                                                                                                   
           8                   =    "Thyroid"                                                                                                                                                      
           9                   =    "Larynx"                                                                                                                                                       
           10                  =    "Colon (intestine) cancer"                                                                                                                                     
           11                  =    "Esophageal (esophagus)"                                                                                                                                       
           12                  =    "Liver cancer"                                                                                                                                                 
           13                  =    "Pancreatic (pancreas) cancer"                                                                                                                                 
           14                  =    "Rectal (rectum) cancer"                                                                                                                                       
           15                  =    "Stomach"                                                                                                                                                      
           16                  =    "Hodgkins Lymphoma (Hodgkins disease)"                                                                                                                       
           17                  =    "Leukemia (blood) cancer"                                                                                                                                      
           18                  =    "Non-Hodgkins Lymphoma"                                                                                                                                       
           19                  =    "Prostate cancer"                                                                                                                                              
           20                  =    "Testicular cancer"                                                                                                                                            
           21                  =    "Melanoma"                                                                                                                                                     
           22                  =    "Other skin cancer"                                                                                                                                            
           23                  =    "Heart"                                                                                                                                                        
           24                  =    "Lung"                                                                                                                                                         
           25                  =    "Bladder cancer"                                                                                                                                               
           26                  =    "Renal (kidney) cancer"                                                                                                                                        
           27                  =    "Bone"                                                                                                                                                         
           28                  =    "Brain"                                                                                                                                                        
           29                  =    "Neuroblastoma"                                                                                                                                                
           30                  =    "Other"                                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CNCRAGE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 97        =    "Age in years (97=97 or older)"                                                                                                                                
           98                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CNCRDIFF                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Only one"                                                                                                                                                     
           2                   =    "Two"                                                                                                                                                          
           3                   =    "Three or more"                                                                                                                                                
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE COLGHOUS                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE COPDBRTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE COPDBTST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE COPDCOGH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE COPDFLEM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE COPDSMOK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of years"                                                                                                                                              
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "Never smoked or smoked less than one year"                                                                                                                    
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CP1DEMO                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 5         =    "Enter number (1-5)"                                                                                                                                           
           6                   =    "Six or more"                                                                                                                                                  
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "None"                                                                                                                                                         
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGV1HRS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Up to 8 hours per week"                                                                                                                                       
           2                   =    "9 to 19 hours per week"                                                                                                                                       
           3                   =    "20 to 39 hours per week"                                                                                                                                      
           4                   =    "40 hours or more"                                                                                                                                             
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGV1LNG                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Less than 30 days"                                                                                                                                            
           2                   =    "1 month to less than 6 months"                                                                                                                                
           3                   =    "6 months to less than 2 years"                                                                                                                                
           4                   =    "2 years to less than 5 years"                                                                                                                                 
           5                   =    "More than 5 years"                                                                                                                                            
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGV1PRB                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Arthritis/Rheumatism"                                                                                                                                         
           2                   =    "Asthma"                                                                                                                                                       
           3                   =    "Cancer"                                                                                                                                                       
           4                   =    "Chronic respiratory conditions such as Emphysema or COPD"                                                                                                     
           5                   =    "Dementia or other Cognitive Impairment Disorders"                                                                                                             
           6                   =    "Developmental Disabilities such as Autism, Downs Syndrome, and Spina Bifida"                                                                                 
           7                   =    "Diabetes"                                                                                                                                                     
           8                   =    "Heart Disease, Hypertension, Stroke"                                                                                                                          
           9                   =    "Human Immunodeficiency Virus Infection (HIV)"                                                                                                                 
           10                  =    "Mental Illnesses, such as Anxiety, Depression, or Schizophrenia"                                                                                              
           11                  =    "Other organ failure or diseases such as kidney or liver problems"                                                                                             
           12                  =    "Substance Abuse or Addiction Disorders"                                                                                                                       
           13                  =    "Injuries, including broken bones"                                                                                                                             
           14                  =    "Old age/infirmity/frailty"                                                                                                                                    
           15                  =    "Other"                                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGV2REL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Mother"                                                                                                                                                       
           2                   =    "Father"                                                                                                                                                       
           3                   =    "Mother-in-law"                                                                                                                                                
           4                   =    "Father-in-law"                                                                                                                                                
           5                   =    "Child"                                                                                                                                                        
           6                   =    "Husband"                                                                                                                                                      
           7                   =    "Wife"                                                                                                                                                         
           8                   =    "Same-sex partner"                                                                                                                                             
           9                   =    "Brother or brother-in-law"                                                                                                                                    
           10                  =    "Sister or sister-in-law"                                                                                                                                      
           11                  =    "Grandmother"                                                                                                                                                  
           12                  =    "Grandfather"                                                                                                                                                  
           13                  =    "Grandchild"                                                                                                                                                   
           14                  =    "Other relative"                                                                                                                                               
           15                  =    "Non-relative/Family friend"                                                                                                                                   
           16                  =    "Unmarried partner"                                                                                                                                            
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGV3MST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Classes about giving care, such as giving medications"                                                                                                        
           2                   =    "Help in getting access to services"                                                                                                                           
           3                   =    "Support groups"                                                                                                                                               
           4                   =    "Individual counseling to help cope with giving care"                                                                                                          
           5                   =    "Respite care"                                                                                                                                                 
           6                   =    "You dont need any of these support services"                                                                                                                 
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGVEXPT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGVHOUS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CRGVPERS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRV1CTL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, with medication (or treatment)"                                                                                                                          
           2                   =    "Yes, without medication (or treatment)"                                                                                                                       
           3                   =    "No, with medication (or treatment)"                                                                                                                           
           4                   =    "No, without medication (or treatment)"                                                                                                                        
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRV1DOC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Cancer Surgeon"                                                                                                                                               
           2                   =    "Family Practitioner"                                                                                                                                          
           3                   =    "General Surgeon"                                                                                                                                              
           4                   =    "Gynecologic Oncologist"                                                                                                                                       
           5                   =    "General Practitioner, Internist"                                                                                                                              
           6                   =    "Plastic Surgeon, Reconstructive Surgeon"                                                                                                                      
           7                   =    "Medical Oncologist"                                                                                                                                           
           8                   =    "Radiation Oncologist"                                                                                                                                         
           9                   =    "Urologist"                                                                                                                                                    
           10                  =    "Other"                                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRV2TRT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No, Ive completed treatment"                                                                                                                                 
           3                   =    "No, Ive refused treatment"                                                                                                                                   
           4                   =    "No, I havent started treatment"                                                                                                                              
           5                   =    "Treatment was not needed"                                                                                                                                     
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVCLIN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVDEIN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVINSR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVINST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVPAIN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVRTRN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CSRVSUM                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CTEL1NUM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CTELE1NM                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE CVD3STRK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CVD4CRHD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE CVD4INFR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DEAF                                                                                                                                                                                    
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DECIDE                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DELAY1ME                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "You couldnt get through on the telephone"                                                                                                                    
           2                   =    "You couldnt get an appointment soon enough"                                                                                                                  
           3                   =    "Once you got there, you had to wait too long to see the doctor"                                                                                               
           4                   =    "The (clinic/doctors) office wasnt open when you got there."                                                                                                 
           5                   =    "You didnt have transportation"                                                                                                                               
           6                   =    "Other"                                                                                                                                                        
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           8                   =    "No, I did not delay getting medical care/did not need medical care"                                                                                           
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIA3BETE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "Yes, but female told only during pregnancy"                                                                                                                   
           3                   =    "No"                                                                                                                                                           
           4                   =    "No, pre-diabetes or borderline diabetes"                                                                                                                      
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIAB2AGE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 97        =    "Age in years  [97 = 97 and older]"                                                                                                                            
           98                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIABEDU                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIABEYE                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIFFALON                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIFFDRES                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DIFFWALK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DOCTDIAB                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times  [76=76 or more]"                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DRNK2DRI                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times"                                                                                                                                              
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DRNK35GE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of Times"                                                                                                                                              
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE DRNK5ANY                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused/Missing"                                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE DROCDY3_                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0                   =    "No Drink-Occasions per day"                                                                                                                                   
           1       - 899       =    "Drink-Occasions per day"                                                                                                                                      
           900                 =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE DRVISITS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times"                                                                                                                                              
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE ECIGARET                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE ECIGNOW                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Every day"                                                                                                                                                    
           2                   =    "Some days"                                                                                                                                                    
           3                   =    "Not at all"                                                                                                                                                   
           7                   =    "Dont know / Not sure"                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE EDUCA                                                                                                                                                                                   
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never attended school or only kindergarten"                                                                                                                   
           2                   =    "Grades 1 through 8 (Elementary)"                                                                                                                              
           3                   =    "Grades 9 through 11 (Some high school)"                                                                                                                       
           4                   =    "Grade 12 or GED (High school graduate)"                                                                                                                       
           5                   =    "College 1 year to 3 years (Some college or technical school)"                                                                                                 
           6                   =    "College 4 years or more (College graduate)"                                                                                                                   
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE EMPLOY1F                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Employed for wages"                                                                                                                                           
           2                   =    "Self-employed"                                                                                                                                                
           3                   =    "Out of work for 1 year or more"                                                                                                                               
           4                   =    "Out of work for less than 1 year"                                                                                                                             
           5                   =    "A homemaker"                                                                                                                                                  
           6                   =    "A student"                                                                                                                                                    
           7                   =    "Retired"                                                                                                                                                      
           8                   =    "Unable to work"                                                                                                                                               
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE EXER2ANY                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE EYE1EXAM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past month (anytime less than 1 month ago)"                                                                                                        
           2                   =    "Within the past year (1 month but less than 12 months ago)"                                                                                                   
           3                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           4                   =    "2 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "Never"                                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FALL12MN                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times  [76=76 or more]"                                                                                                                             
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FALL3INJ                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of falls [76=76 or more]"                                                                                                                              
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FEELNERV                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never"                                                                                                                                                        
           2                   =    "For several days"                                                                                                                                             
           3                   =    "For more than half the days"                                                                                                                                  
           4                   =    "Nearly every day"                                                                                                                                             
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FEET3CHK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           101     - 199       =    "Times per day"                                                                                                                                                
           201     - 299       =    "Times per week"                                                                                                                                               
           301     - 399       =    "Times per month"                                                                                                                                              
           401     - 499       =    "Times per year"                                                                                                                                               
           555                 =    "No feet"                                                                                                                                                      
           777                 =    "Dont know/Not sure"                                                                                                                                          
           888                 =    "Never"                                                                                                                                                        
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FEETCHK                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of times  [76=76 or more]"                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FLSHT2MY                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           12007   - 122008    =    "Month / Year"                                                                                                                                                 
           777777              =    "Dont know/Not Sure"                                                                                                                                          
           999999              =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FLU6SHOT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE FMONTH                                                                                                                                                                                  
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "January"                                                                                                                                                      
           2                   =    "February"                                                                                                                                                     
           3                   =    "March"                                                                                                                                                        
           4                   =    "April"                                                                                                                                                        
           5                   =    "May"                                                                                                                                                          
           6                   =    "June"                                                                                                                                                         
           7                   =    "July"                                                                                                                                                         
           8                   =    "August"                                                                                                                                                       
           9                   =    "September"                                                                                                                                                    
           10                  =    "October"                                                                                                                                                      
           11                  =    "November"                                                                                                                                                     
           12                  =    "December"                                                                                                                                                     
           ;                                                                                                                                                                                       
     VALUE GENHLTH                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Excellent"                                                                                                                                                    
           2                   =    "Very good"                                                                                                                                                    
           3                   =    "Good"                                                                                                                                                         
           4                   =    "Fair"                                                                                                                                                         
           5                   =    "Poor"                                                                                                                                                         
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HAD1SGCO                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Sigmoidoscopy"                                                                                                                                                
           2                   =    "Colonoscopy"                                                                                                                                                  
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HAD2HYST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HAD2PAP                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HAD3SIGM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HADMAM                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HAV3ARTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HEIGHT                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           200     - 711       =    "Height (ft/inches)"                                                                                                                                           
           7777                =    "Dont know/Not sure"                                                                                                                                          
           9000    - 9998      =    "Height (meters/centimeters)"                                                                                                                                  
           9999                =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HHADULT                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of adults"                                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HIV3TSTD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           11985   - 122014    =    "Code month and year"                                                                                                                                          
           771985  - 772014    =    "Unknown month and known year"                                                                                                                                 
           777777              =    "Dont know/Not sure"                                                                                                                                          
           999999              =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HIV5RISK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HIV6TST                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HLTH1CVR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "A plan purchased through an employer or union"                                                                                                                
           2                   =    "A plan that you or another family member buys on your own"                                                                                                    
           3                   =    "Medicare"                                                                                                                                                     
           4                   =    "Medicaid or other state program"                                                                                                                              
           5                   =    "TRICARE (formerly CHAMPUS), VA, or Military"                                                                                                                  
           6                   =    "Alaska Native, Indian Health Service, Tribal Health Services"                                                                                                 
           7                   =    "Some other source"                                                                                                                                            
           8                   =    "None (no coverage)"                                                                                                                                           
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HLTH1PLN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HOWLONG                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HPLSTTST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HPV2ADVC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           3                   =    "Doctor refused when asked"                                                                                                                                    
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HPVADSHT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 2         =    "Number of shots"                                                                                                                                              
           3                   =    "All shots"                                                                                                                                                    
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HPVTEST                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE HT4IN                                                                                                                                                                                   
           .                   =    "Dont know/Refused/Not asked or Missing"                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           36      - 95        =    "Height in inches"                                                                                                                                             
           ;                                                                                                                                                                                       
     VALUE HT4M                                                                                                                                                                                    
           .                   =    "Dont know/Refused/Not asked or Missing"                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           91      - 244       =    "Height in meters [2 implied decimal places]"                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE IMFVPLAC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "A doctors office or health maintenance organization (HMO)"                                                                                                   
           2                   =    "A health department"                                                                                                                                          
           3                   =    "Another type of clinic or health center (a community health center)"                                                                                          
           4                   =    "A senior, recreation, or community center"                                                                                                                    
           5                   =    "A store (supermarket, drug store)"                                                                                                                            
           6                   =    "A hospital (inpatient)"                                                                                                                                       
           7                   =    "An emergency room"                                                                                                                                            
           8                   =    "Workplace"                                                                                                                                                    
           9                   =    "Some other kind of place"                                                                                                                                     
           10                  =    "Received vaccination in Canada/Mexico"                                                                                                                        
           11                  =    "A school"                                                                                                                                                     
           77                  =    "Dont know / Not sure"                                                                                                                                        
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE IN2COME                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Less than $10,000"                                                                                                                                            
           2                   =    "Less than $15,000 ($10,000 to less than $15,000)"                                                                                                             
           3                   =    "Less than $20,000 ($15,000 to less than $20,000)"                                                                                                             
           4                   =    "Less than $25,000 ($20,000 to less than $25,000)"                                                                                                             
           5                   =    "Less than $35,000 ($25,000 to less than $35,000)"                                                                                                             
           6                   =    "Less than $50,000 ($35,000 to less than $50,000)"                                                                                                             
           7                   =    "Less than $75,000 ($50,000 to less than $75,000)"                                                                                                             
           8                   =    "$75,000 or more"                                                                                                                                              
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE INDORTAN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0       - 365       =    "Numer of times"                                                                                                                                               
           777                 =    "Dont know/Not Sure"                                                                                                                                          
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE INSULIN                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LANDLINE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LAST2PAP                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LAST2SMK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past month (less than 1 month ago)"                                                                                                                
           2                   =    "Within the past 3 months (1 month but less than 3 months ago)"                                                                                                
           3                   =    "Within the past 6 months (3 months but less than 6 months ago)"                                                                                               
           4                   =    "Within the past year (6 months but less than 1 year ago)"                                                                                                     
           5                   =    "Within the past 5 years (1 year but less than 5 years ago)"                                                                                                   
           6                   =    "Within the past 10 years (5 years but less than 10 years ago)"                                                                                                
           7                   =    "10 years or more"                                                                                                                                             
           8                   =    "Never smoked regularly"                                                                                                                                       
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LAST3SIG                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "Within the past 10 years (5 years but less than 10 years ago)"                                                                                                
           6                   =    "10 or more years ago"                                                                                                                                         
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LAST4DEN                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 5 years (2 years but less than 5 years ago)"                                                                                                  
           4                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "Never"                                                                                                                                                        
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LCSCTSCN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, to check for lung cancer"                                                                                                                                
           2                   =    "No (did not have a CT scan)"                                                                                                                                  
           3                   =    "Had a CT scan, but for some other reason"                                                                                                                     
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LCSFIRST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 100       =    "Age in Years"                                                                                                                                                 
           777                 =    "Dont know/Not Sure"                                                                                                                                          
           888                 =    "Never smoked cigarettes regularly"                                                                                                                            
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LCSLAST                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 100       =    "Age in Years"                                                                                                                                                 
           777                 =    "Dont know/Not Sure"                                                                                                                                          
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LCSNUMCG                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 300       =    "Number of cigarettes"                                                                                                                                         
           777                 =    "Dont know/Not Sure"                                                                                                                                          
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LENGEXAM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LST3BLDS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE LSTCOVRG                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "6 months or less"                                                                                                                                             
           2                   =    "More than 6 months, but not more than 1 year ago"                                                                                                             
           3                   =    "More than 1 year, but not more than 3 years ago"                                                                                                              
           4                   =    "More than 3 years"                                                                                                                                            
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MARI1JAN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 30        =    "Number of Days"                                                                                                                                               
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MARITAL                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Married"                                                                                                                                                      
           2                   =    "Divorced"                                                                                                                                                     
           3                   =    "Widowed"                                                                                                                                                      
           4                   =    "Separated"                                                                                                                                                    
           5                   =    "Never married"                                                                                                                                                
           6                   =    "A member of an unmarried couple"                                                                                                                              
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MAXDRNKS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 76        =    "Number of drinks"                                                                                                                                             
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "Invalid response"                                                                                                                                             
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MED1BILL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MEDCOST                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MEDICARE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MEDS1COS                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           3                   =    "No medication was prescribed"                                                                                                                                 
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MENTHLTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 30        =    "Number of days"                                                                                                                                               
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE MSCODE                                                                                                                                                                                  
           .                   =    "GU, PR, VI, or cell phone"                                                                                                                                    
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "In the center city of an MSA"                                                                                                                                 
           2                   =    "Outside the center city of an MSA but inside the county containing the center city"                                                                           
           3                   =    "Inside a suburban county of the MSA"                                                                                                                          
           4                   =    "In an MSA that has no center city"                                                                                                                            
           5                   =    "Not in an MSA"                                                                                                                                                
           ;                                                                                                                                                                                       
     VALUE NO121COV                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE NUM3BURN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0       - 365       =    "Number of times"                                                                                                                                              
           777                 =    "Dont know/Not Sure"                                                                                                                                          
           999                 =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE NUM3HHOL                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE NUM3PHON                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 5         =    "Residential telephone number(s)"                                                                                                                              
           6                   =    "Residential telephone numbers"                                                                                                                                
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           8                   =    "None"                                                                                                                                                         
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE O3RACE                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           10                  =    "White"                                                                                                                                                        
           20                  =    "Black or African American"                                                                                                                                    
           30                  =    "American Indian or Alaska Native"                                                                                                                             
           40                  =    "Asian"                                                                                                                                                        
           41                  =    "Asian Indian"                                                                                                                                                 
           42                  =    "Chinese"                                                                                                                                                      
           43                  =    "Filipino"                                                                                                                                                     
           44                  =    "Japanese"                                                                                                                                                     
           45                  =    "Korean"                                                                                                                                                       
           46                  =    "Vietnamese"                                                                                                                                                   
           47                  =    "Other Asian"                                                                                                                                                  
           50                  =    "Pacific Islander"                                                                                                                                             
           51                  =    "Native Hawaiian"                                                                                                                                              
           52                  =    "Guamanian or Chamorro"                                                                                                                                        
           53                  =    "Samoan"                                                                                                                                                       
           54                  =    "Other Pacific Islander"                                                                                                                                       
           60                  =    "Other"                                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCDM1DEC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Doctor/nurse/health care provider"                                                                                                                            
           2                   =    "Spouse/significant other"                                                                                                                                     
           3                   =    "Other family member"                                                                                                                                          
           4                   =    "Friend/non-relative"                                                                                                                                          
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCPSA1DE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "You made the decision alone"                                                                                                                                  
           2                   =    "Your doctor, nurse, or health care provider made the decision alone"                                                                                          
           3                   =    "You and one or more other persons made the decision together"                                                                                                 
           4                   =    "You dont remember how the decision was made"                                                                                                                 
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCPSA1DI                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCPSA1RE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCPSA1RS                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Part of a routine exam"                                                                                                                                       
           2                   =    "Because of a prostate problem"                                                                                                                                
           3                   =    "Because of a family history of prostate cancer"                                                                                                               
           4                   =    "Because you were told you had prostate cancer"                                                                                                                
           5                   =    "Some other reason"                                                                                                                                            
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PCPSA3AD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PDIABTST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PERS2DOC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, only one"                                                                                                                                                
           2                   =    "More than one"                                                                                                                                                
           3                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PHYSHLTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 30        =    "Number of days"                                                                                                                                               
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PNEU4VAC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE POORHLTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 30        =    "Number of days"                                                                                                                                               
           77                  =    "Dont know/Not sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PRE1DIAB                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "Yes, during pregnancy"                                                                                                                                        
           3                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PRECALL                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "To be called"                                                                                                                                                 
           3                   =    "Pre-screened as non-working number"                                                                                                                           
           4                   =    "cell phone - PRO-T-S"                                                                                                                                         
           5                   =    "Pre-screened as business number"                                                                                                                              
           6                   =    "cell phone - Interviewer"                                                                                                                                     
           7                   =    "cell phone - unknown status"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE PREGNANT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PROFEXAM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PSA1TEST                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PSATIME                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Within the past year (anytime less than 12 months ago)"                                                                                                       
           2                   =    "Within the past 2 years (1 year but less than 2 years ago)"                                                                                                   
           3                   =    "Within the past 3 years (2 years but less than 3 years ago)"                                                                                                  
           4                   =    "Within the past 5 years (3 years but less than 5 years ago)"                                                                                                  
           5                   =    "5 or more years ago"                                                                                                                                          
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PVT1RESD                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           3                   =    "No, business phone only"                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE PVT3RESD                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           ;                                                                                                                                                                                       
     VALUE QSTLANG                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "English"                                                                                                                                                      
           2                   =    "Spanish"                                                                                                                                                      
           3       - 99        =    "Other"                                                                                                                                                        
           ;                                                                                                                                                                                       
     VALUE RCS2BRAC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           10                  =    "White"                                                                                                                                                        
           20                  =    "Black or African American"                                                                                                                                    
           30                  =    "American Indian or Alaska Native"                                                                                                                             
           40                  =    "Asian"                                                                                                                                                        
           41                  =    "Asian Indian"                                                                                                                                                 
           42                  =    "Chinese"                                                                                                                                                      
           43                  =    "Filipino"                                                                                                                                                     
           44                  =    "Japanese"                                                                                                                                                     
           45                  =    "Korean"                                                                                                                                                       
           46                  =    "Vietnamese"                                                                                                                                                   
           47                  =    "Other Asian"                                                                                                                                                  
           50                  =    "Pacific Islander"                                                                                                                                             
           51                  =    "Native Hawaiian"                                                                                                                                              
           52                  =    "Guamanian or Chamorro"                                                                                                                                        
           53                  =    "Samoan"                                                                                                                                                       
           54                  =    "Other Pacific Islander"                                                                                                                                       
           60                  =    "Other"                                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RCS2RLTN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Parent (include biologic, step, or adoptive parent)"                                                                                                          
           2                   =    "Grandparent"                                                                                                                                                  
           3                   =    "Foster parent or guardian"                                                                                                                                    
           4                   =    "Sibling (include biologic, step, and adoptive sibling)"                                                                                                       
           5                   =    "Other relative"                                                                                                                                               
           6                   =    "Not related in any way"                                                                                                                                       
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RCSGENDR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Boy"                                                                                                                                                          
           2                   =    "Girl"                                                                                                                                                         
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RENT1HOM                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Own"                                                                                                                                                          
           2                   =    "Rent"                                                                                                                                                         
           3                   =    "Other arrangement"                                                                                                                                            
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RMV4TETH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "1 to 5"                                                                                                                                                       
           2                   =    "6 or more, but not all"                                                                                                                                       
           3                   =    "All"                                                                                                                                                          
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "None"                                                                                                                                                         
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RSN1MRJN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "For medical reasons (like to treat or decrease symptoms of a health condition)"                                                                               
           2                   =    "For non-medical reasons (like to have fun or fit in)"                                                                                                         
           3                   =    "For both medical and non-medical reasons"                                                                                                                     
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE RSP1STAT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Alabama"                                                                                                                                                      
           2                   =    "Alaska"                                                                                                                                                       
           4                   =    "Arizona"                                                                                                                                                      
           5                   =    "Arkansas"                                                                                                                                                     
           6                   =    "California"                                                                                                                                                   
           8                   =    "Colorado"                                                                                                                                                     
           9                   =    "Connecticut"                                                                                                                                                  
           10                  =    "Delaware"                                                                                                                                                     
           11                  =    "District of Columbia"                                                                                                                                         
           12                  =    "Florida"                                                                                                                                                      
           13                  =    "Georgia"                                                                                                                                                      
           15                  =    "Hawaii"                                                                                                                                                       
           16                  =    "Idaho"                                                                                                                                                        
           17                  =    "Illinois"                                                                                                                                                     
           18                  =    "Indiana"                                                                                                                                                      
           19                  =    "Iowa"                                                                                                                                                         
           20                  =    "Kansas"                                                                                                                                                       
           21                  =    "Kentucky"                                                                                                                                                     
           22                  =    "Louisiana"                                                                                                                                                    
           23                  =    "Maine"                                                                                                                                                        
           24                  =    "Maryland"                                                                                                                                                     
           25                  =    "Massachusetts"                                                                                                                                                
           26                  =    "Michigan"                                                                                                                                                     
           27                  =    "Minnesota"                                                                                                                                                    
           28                  =    "Mississippi"                                                                                                                                                  
           29                  =    "Missouri"                                                                                                                                                     
           30                  =    "Montana"                                                                                                                                                      
           31                  =    "Nebraska"                                                                                                                                                     
           32                  =    "Nevada"                                                                                                                                                       
           33                  =    "New Hampshire"                                                                                                                                                
           34                  =    "New Jersey"                                                                                                                                                   
           35                  =    "New Mexico"                                                                                                                                                   
           36                  =    "New York"                                                                                                                                                     
           37                  =    "North Carolina"                                                                                                                                               
           38                  =    "North Dakota"                                                                                                                                                 
           39                  =    "Ohio"                                                                                                                                                         
           40                  =    "Oklahoma"                                                                                                                                                     
           41                  =    "Oregon"                                                                                                                                                       
           42                  =    "Pennsylvania"                                                                                                                                                 
           44                  =    "Rhode Island"                                                                                                                                                 
           45                  =    "South Carolina"                                                                                                                                               
           46                  =    "South Dakota"                                                                                                                                                 
           47                  =    "Tennessee"                                                                                                                                                    
           48                  =    "Texas"                                                                                                                                                        
           49                  =    "Utah"                                                                                                                                                         
           50                  =    "Vermont"                                                                                                                                                      
           51                  =    "Virginia"                                                                                                                                                     
           53                  =    "Washington"                                                                                                                                                   
           54                  =    "West Virginia"                                                                                                                                                
           55                  =    "Wisconsin"                                                                                                                                                    
           56                  =    "Wyoming"                                                                                                                                                      
           66                  =    "Guam"                                                                                                                                                         
           72                  =    "Puerto Rico"                                                                                                                                                  
           78                  =    "Virgin Islands"                                                                                                                                               
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SEATBELT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Nearly always"                                                                                                                                                
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Seldom"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           7                   =    "Dont know/Not sure"                                                                                                                                          
           8                   =    "Never drive or ride in a car"                                                                                                                                 
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SECSCRFL                                                                                                                                                                                
           .                   =    "Missing or Not Used"                                                                                                                                          
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0                   =    "Undetermined/Residential"                                                                                                                                     
           1                   =    "No Answer"                                                                                                                                                    
           2                   =    "Busy"                                                                                                                                                         
           3                   =    "Fax/Modem"                                                                                                                                                    
           4                   =    "Language Barrier"                                                                                                                                             
           5                   =    "Privacy Manager"                                                                                                                                              
           6                   =    "Residential Voice Mail"                                                                                                                                       
           7                   =    "Residence/Phone Answered"                                                                                                                                     
           8                   =    "Cellular Number"                                                                                                                                              
           9                   =    "Business/Non-Working"                                                                                                                                         
           ;                                                                                                                                                                                       
     VALUE SEX1F                                                                                                                                                                                   
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Male"                                                                                                                                                         
           2                   =    "Female"                                                                                                                                                       
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SHIN2GLE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SLEP1DAY                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 14        =    "Number of days [1-14]"                                                                                                                                        
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           88                  =    "None"                                                                                                                                                         
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SLEP1SNO                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SLEP1TIM                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 24        =    "Number of hours [1-24]"                                                                                                                                       
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SLEPBRTH                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SMOK100_                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SMOK2DAY                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Every day"                                                                                                                                                    
           2                   =    "Some days"                                                                                                                                                    
           3                   =    "Not at all"                                                                                                                                                   
           7                   =    "Dont Know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SOFEMALE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Lesbian or Gay"                                                                                                                                               
           2                   =    "Straight, that is, not gay"                                                                                                                                   
           3                   =    "Bisexual"                                                                                                                                                     
           4                   =    "Something else"                                                                                                                                               
           7                   =    "I dont know the answer"                                                                                                                                      
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SOMALE                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Gay"                                                                                                                                                          
           2                   =    "Straight, that is, not gay"                                                                                                                                   
           3                   =    "Bisexual"                                                                                                                                                     
           4                   =    "Something else"                                                                                                                                               
           7                   =    "I dont know the answer"                                                                                                                                      
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE STOP2SMK                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE STOPWORY                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never"                                                                                                                                                        
           2                   =    "For several days"                                                                                                                                             
           3                   =    "For more than half the days"                                                                                                                                  
           4                   =    "Nearly every day"                                                                                                                                             
           7                   =    "Dont know/Not sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE SUNPRTCT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always"                                                                                                                                                       
           2                   =    "Most of the time"                                                                                                                                             
           3                   =    "Sometimes"                                                                                                                                                    
           4                   =    "Rarely"                                                                                                                                                       
           5                   =    "Never"                                                                                                                                                        
           6                   =    "Dont stay outside for more than one hour on warm sunny days"                                                                                                 
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           8                   =    "Dont go outside at all on warm sunny days"                                                                                                                   
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE TETAN1US                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, received Tdap"                                                                                                                                           
           2                   =    "Yes, received tetanus shot, but not Tdap"                                                                                                                     
           3                   =    "Yes, received tetanus shot but not sure what type"                                                                                                            
           4                   =    "No, did not receive any tetanus shot in the past 10 years"                                                                                                    
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE TRNSGNDR                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes, Transgender, male-to-female"                                                                                                                             
           2                   =    "Yes, Transgender, female to male"                                                                                                                             
           3                   =    "Yes, Transgender, gender nonconforming"                                                                                                                       
           4                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE USE2MRJN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Smoke it (for example, in a joint, bong, pipe, or blunt)"                                                                                                     
           2                   =    "Eat it (for example, in brownies, cakes, cookies, or candy)"                                                                                                  
           3                   =    "Drink it (for example, in tea, cola, alcohol)"                                                                                                                
           4                   =    "Vaporize it (for example, in an e-cigarette-like vaporizer or other vaporizing device)"                                                                       
           5                   =    "Dab it (for example, using waxes or concentrates)"                                                                                                            
           6                   =    "Use it some other way"                                                                                                                                        
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE USE3NOW                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Every day"                                                                                                                                                    
           2                   =    "Some days"                                                                                                                                                    
           3                   =    "Not at all"                                                                                                                                                   
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE VET3ERAN                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           7                   =    "Dont know/Not Sure"                                                                                                                                          
           9                   =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE WEIGHT                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           50      - 999       =    "Weight (pounds)"                                                                                                                                              
           7777                =    "Dont know/Not sure"                                                                                                                                          
           9000    - 9998      =    "Weight (kilograms)"                                                                                                                                           
           9999                =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE WKDAYOUT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Less than half an hour"                                                                                                                                       
           2                   =    "(More than half an hour) up to 1 hour"                                                                                                                        
           3                   =    "(More than 1 hour) up to 2 hours"                                                                                                                             
           4                   =    "(More than 2 hours) up to 3 hours"                                                                                                                            
           5                   =    "(More than 3 hours) up to 4 hours"                                                                                                                            
           6                   =    "(More than 4 hours) up to 5 hours"                                                                                                                            
           7                   =    "(More than 5) up to 6 hours"                                                                                                                                  
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE WKENDOUT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Less than half an hour"                                                                                                                                       
           2                   =    "(More than half an hour) up to 1 hour"                                                                                                                        
           3                   =    "(More than 1 hour) up to 2 hours"                                                                                                                             
           4                   =    "(More than 2 hours) up to 3 hours"                                                                                                                            
           5                   =    "(More than 3 hours) up to 4 hours"                                                                                                                            
           6                   =    "(More than 4 hours) up to 5 hours"                                                                                                                            
           7                   =    "(More than 5) up to 6 hours"                                                                                                                                  
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _1ASTHMS                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Current"                                                                                                                                                      
           2                   =    "Former"                                                                                                                                                       
           3                   =    "Never"                                                                                                                                                        
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _1CASTHM                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _1LTASTH                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _21RACEG                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Non-Hispanic White"                                                                                                                                           
           2                   =    "Non-White or Hispanic"                                                                                                                                        
           9                   =    "Dont know/Not sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _21RFMAM                                                                                                                                                                                
           .                   =    "Missing or Age less than 40 or Male"                                                                                                                          
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _2DENSTR                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Listed"                                                                                                                                                       
           2                   =    "Unlisted"                                                                                                                                                     
           3                   =    "Zero block"                                                                                                                                                   
           9                   =    "Not Applicable"                                                                                                                                               
           ;                                                                                                                                                                                       
     VALUE _2RFSEAT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always or Almost Always Wear Seat Belt"                                                                                                                       
           2                   =    "Sometimes, Seldom, or Never Wear Seat Belt"                                                                                                                   
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _34RFPAP                                                                                                                                                                                
           .                   =    "Missing or Male"                                                                                                                                              
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received a Pap test within the past 3 years."                                                                                                                 
           2                   =    "Did not receive a Pap test within the past 3 years."                                                                                                          
           ;                                                                                                                                                                                       
     VALUE _3AIDTST                                                                                                                                                                                
           .                   =    "Not asked or missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _3PNEUMO                                                                                                                                                                                
           .                   =    "Age Less Than 65"                                                                                                                                             
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _3RACEGR                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White only, Non-Hispanic"                                                                                                                                     
           2                   =    "Black only, Non-Hispanic"                                                                                                                                     
           3                   =    "Other race only, Non-Hispanic"                                                                                                                                
           4                   =    "Multiracial, Non-Hispanic"                                                                                                                                    
           5                   =    "Hispanic"                                                                                                                                                     
           9                   =    "Dont know/Not sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _3RFSEAT                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Always Wear Seat Belt"                                                                                                                                        
           2                   =    "Dont Always Wear Seat Belt"                                                                                                                                  
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _3RFSMOK                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _3SMOKER                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Current smoker - now smokes every day"                                                                                                                        
           2                   =    "Current smoker - now smokes some days"                                                                                                                        
           3                   =    "Former smoker"                                                                                                                                                
           4                   =    "Never smoked"                                                                                                                                                 
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _5022MAM                                                                                                                                                                                
           .                   =    "Missing, Age less than 50 or greater than 74 or Male"                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received a mammogram within the past 2 years."                                                                                                                
           2                   =    "Did not receive a mammogram within the past 2 years."                                                                                                         
           ;                                                                                                                                                                                       
     VALUE _5BMI                                                                                                                                                                                   
           .                   =    "Dont know/Refused/Missing"                                                                                                                                   
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1       - 9999      =    "1 or greater"                                                                                                                                                 
           ;                                                                                                                                                                                       
     VALUE _5RFBING                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _5RFBMI                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _6FLSHOT                                                                                                                                                                                
           .                   =    "Age Less Than 65"                                                                                                                                             
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _6RFDRHV                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _AGE65YR                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Age 18 to 64"                                                                                                                                                 
           2                   =    "Age 65 or older"                                                                                                                                              
           3                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _AGE80F                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           18      - 24        =    "Imputed Age 18 to 24"                                                                                                                                         
           25      - 29        =    "Imputed Age 25 to 29"                                                                                                                                         
           30      - 34        =    "Imputed Age 30 to 34"                                                                                                                                         
           35      - 39        =    "Imputed Age 35 to 39"                                                                                                                                         
           40      - 44        =    "Imputed Age 40 to 44"                                                                                                                                         
           45      - 49        =    "Imputed Age 45 to 49"                                                                                                                                         
           50      - 54        =    "Imputed Age 50 to 54"                                                                                                                                         
           55      - 59        =    "Imputed Age 55 to 59"                                                                                                                                         
           60      - 64        =    "Imputed Age 60 to 64"                                                                                                                                         
           65      - 69        =    "Imputed Age 65 to 69"                                                                                                                                         
           70      - 74        =    "Imputed Age 70 to 74"                                                                                                                                         
           75      - 79        =    "Imputed Age 75 to 79"                                                                                                                                         
           80      - 99        =    "Imputed Age 80 or older"                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _AGEG5YR                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Age 18 to 24"                                                                                                                                                 
           2                   =    "Age 25 to 29"                                                                                                                                                 
           3                   =    "Age 30 to 34"                                                                                                                                                 
           4                   =    "Age 35 to 39"                                                                                                                                                 
           5                   =    "Age 40 to 44"                                                                                                                                                 
           6                   =    "Age 45 to 49"                                                                                                                                                 
           7                   =    "Age 50 to 54"                                                                                                                                                 
           8                   =    "Age 55 to 59"                                                                                                                                                 
           9                   =    "Age 60 to 64"                                                                                                                                                 
           10                  =    "Age 65 to 69"                                                                                                                                                 
           11                  =    "Age 70 to 74"                                                                                                                                                 
           12                  =    "Age 75 to 79"                                                                                                                                                 
           13                  =    "Age 80 or older"                                                                                                                                              
           14                  =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _AGE_G                                                                                                                                                                                  
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Age 18 to 24"                                                                                                                                                 
           2                   =    "Age 25 to 34"                                                                                                                                                 
           3                   =    "Age 35 to 44"                                                                                                                                                 
           4                   =    "Age 45 to 54"                                                                                                                                                 
           5                   =    "Age 55 to 64"                                                                                                                                                 
           6                   =    "Age 65 or older"                                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _AL3TETH                                                                                                                                                                                
           .                   =    "Missing or Age Less Than 65"                                                                                                                                  
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No"                                                                                                                                                           
           2                   =    "Yes"                                                                                                                                                          
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _BMI5CAT                                                                                                                                                                                
           .                   =    "Dont know/Refused/Missing"                                                                                                                                   
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Underweight"                                                                                                                                                  
           2                   =    "Normal Weight"                                                                                                                                                
           3                   =    "Overweight"                                                                                                                                                   
           4                   =    "Obese"                                                                                                                                                        
           ;                                                                                                                                                                                       
     VALUE _C1RACE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White only"                                                                                                                                                   
           2                   =    "Black or African American only"                                                                                                                               
           3                   =    "American Indian or Alaskan Native only"                                                                                                                       
           4                   =    "Asian Only"                                                                                                                                                   
           5                   =    "Native Hawaiian or other Pacific Islander only"                                                                                                               
           6                   =    "Other race only"                                                                                                                                              
           7                   =    "Multiracial"                                                                                                                                                  
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _CHISPNC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Child of Hispanic, Latino/a, or Spanish origin"                                                                                                               
           2                   =    "Child not of Hispanic, Latino/a, or Spanish origin"                                                                                                           
           9                   =    "Dont know/Not Sure/Refused/Missing"                                                                                                                          
           ;                                                                                                                                                                                       
     VALUE _CHLDCNT                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "No children in household"                                                                                                                                     
           2                   =    "One child in household"                                                                                                                                       
           3                   =    "Two children in household"                                                                                                                                    
           4                   =    "Three children in household"                                                                                                                                  
           5                   =    "Four children in household"                                                                                                                                   
           6                   =    "Five or more children in household"                                                                                                                           
           9                   =    "Dont know/Not sure/Missing"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _COL10YR                                                                                                                                                                                
           .                   =    "Missing or Age less than 50 or Age greater than 75"                                                                                                           
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received a colonoscopy within the past 10 years"                                                                                                              
           2                   =    "Did not receive a colonoscopy within the past 10 years"                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _CPRACE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White"                                                                                                                                                        
           2                   =    "Black or African American"                                                                                                                                    
           3                   =    "American Indian or Alaskan Native"                                                                                                                            
           4                   =    "Asian"                                                                                                                                                        
           5                   =    "Native Hawaiian or other Pacific Islander"                                                                                                                    
           6                   =    "Other race"                                                                                                                                                   
           7                   =    "No preferred race"                                                                                                                                            
           8                   =    "Multiracial but preferred race not answered"                                                                                                                  
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _CRCREC                                                                                                                                                                                 
           .                   =    "Missing or Age less than 50 or Age greater than 75"                                                                                                           
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received one or more of the recommended CRC tests within the recommended time interval"                                                                       
           2                   =    "Did not receive one or more of the recommended CRC tests within the recommended time interval"                                                                
           ;                                                                                                                                                                                       
     VALUE _DEN3VST                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _DRDX1AR                                                                                                                                                                                
           .                   =    "Dont know/Not Sure/Refused/Missing"                                                                                                                          
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Diagnosed with arthritis"                                                                                                                                     
           2                   =    "Not diagnosed with arthritis"                                                                                                                                 
           ;                                                                                                                                                                                       
     VALUE _DRNKDRV                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Have driven after having too much to drink"                                                                                                                   
           2                   =    "Have not driven after having too much to drink"                                                                                                               
           9                   =    "Dont know/Not Sure/Refused/Missing"                                                                                                                          
           ;                                                                                                                                                                                       
     VALUE _DRNKWEK                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           0                   =    "Did not drink"                                                                                                                                                
           1       - 98999     =    "Number of drinks per week"                                                                                                                                    
           99900               =    "Dont know/Not sure/Refused/Missing"                                                                                                                          
           ;                                                                                                                                                                                       
     VALUE _DUALUSE                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Landline frame with a cell phone"                                                                                                                             
           2                   =    "Cell phone frame with a landline"                                                                                                                             
           3                   =    "Land Line: Cell Phone Occasionally"                                                                                                                           
           4                   =    "Cell Phone: Cell Phone Occasionally"                                                                                                                          
           9                   =    "No Dual Phone Use"                                                                                                                                            
           ;                                                                                                                                                                                       
     VALUE _EDUCAG                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Did not graduate High School"                                                                                                                                 
           2                   =    "Graduated High School"                                                                                                                                        
           3                   =    "Attended College or Technical School"                                                                                                                         
           4                   =    "Graduated from College or Technical School"                                                                                                                   
           9                   =    "Dont know/Not sure/Missing"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _EX3TETH                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Not at risk"                                                                                                                                                  
           2                   =    "At risk"                                                                                                                                                      
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _FOBTFS                                                                                                                                                                                 
           .                   =    "Missing or Age less than 50 or Age greater than 75"                                                                                                           
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Did have had a sigmoidoscopy within the past 5 years and a blood stool test within the past 3 years."                                                         
           2                   =    "Did not receive a sigmoidoscopy within the past 5 years or did not receive a blood stool test within the past 3 years"                                        
           ;                                                                                                                                                                                       
     VALUE _FS5YR                                                                                                                                                                                  
           .                   =    "Missing or Age less than 50 or Age greater than 75"                                                                                                           
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received a sigmoidoscopy within the past 5 years"                                                                                                             
           2                   =    "Did not receive a sigmoidoscopy within the past 5 years"                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _HCV165U                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Have health care coverage"                                                                                                                                    
           2                   =    "Do not have health care coverage"                                                                                                                             
           9                   =    "Dont know/Not Sure, Refused or Missing"                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _HFOB3YR                                                                                                                                                                                
           .                   =    "Missing or Age less than 50 or Age greater than 75"                                                                                                           
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Received a home FOBT within the past 3 years"                                                                                                                 
           2                   =    "Did not receive a home FOBT within the past 3 years"                                                                                                          
           ;                                                                                                                                                                                       
     VALUE _HISPANC                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Hispanic, Latino/a, or Spanish origin"                                                                                                                        
           2                   =    "Not of Hispanic, Latino/a, or Spanish origin"                                                                                                                 
           9                   =    "Dont Know, Refused or Missing"                                                                                                                               
           ;                                                                                                                                                                                       
     VALUE _IMPAGE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           18      - 24        =    "Age 18 to 24"                                                                                                                                                 
           25      - 34        =    "Age 25 to 34"                                                                                                                                                 
           35      - 44        =    "Age 35 to 44"                                                                                                                                                 
           45      - 54        =    "Age 45 to 54"                                                                                                                                                 
           55      - 64        =    "Age 55 to 64"                                                                                                                                                 
           65      - 99        =    "Age 65 or older"                                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _IMPCAGE                                                                                                                                                                                
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "0-4 Years old"                                                                                                                                                
           2                   =    "5-9 Years old"                                                                                                                                                
           3                   =    "10-14 Years old"                                                                                                                                              
           4                   =    "15-17 Years old"                                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _IMPCRAC                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White, non-Hispanic"                                                                                                                                          
           2                   =    "Black or African American, non-Hispanic"                                                                                                                      
           3                   =    "Asian, non-Hispanic"                                                                                                                                          
           4                   =    "American Indian or Alaskan Native, non-Hispanic"                                                                                                              
           5                   =    "Multi-race, non-Hispanic or Other race, non-Hispanic"                                                                                                         
           6                   =    "Hispanic"                                                                                                                                                     
           ;                                                                                                                                                                                       
     VALUE _IMPCSEX                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Male"                                                                                                                                                         
           2                   =    "Female"                                                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _IMPEDUC                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Never attended school or only kindergarten"                                                                                                                   
           2                   =    "Grades 1 through 8 (Elementary)"                                                                                                                              
           3                   =    "Grades 9 through 11 (Some high school)"                                                                                                                       
           4                   =    "Grade 12 or GED (High school graduate)"                                                                                                                       
           5                   =    "College 1 year to 3 years (Some college or technical school)"                                                                                                 
           6                   =    "College 4 years or more (College graduate)"                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _IMPHOME                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Own"                                                                                                                                                          
           2                   =    "Rent"                                                                                                                                                         
           3                   =    "Other arrangement"                                                                                                                                            
           ;                                                                                                                                                                                       
     VALUE _IMPMRTL                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Married"                                                                                                                                                      
           2                   =    "Divorced"                                                                                                                                                     
           3                   =    "Widowed"                                                                                                                                                      
           4                   =    "Separated"                                                                                                                                                    
           5                   =    "Never married"                                                                                                                                                
           6                   =    "A member of an unmarried couple"                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _IMPNPH                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Number of phones"                                                                                                                                             
           2                   =    " "                                                                                                                                                            
           3                   =    " "                                                                                                                                                            
           4                   =    " "                                                                                                                                                            
           5                   =    " "                                                                                                                                                            
           6                   =    " "                                                                                                                                                            
           7                   =    " "                                                                                                                                                            
           8                   =    "8 or more"                                                                                                                                                    
           ;                                                                                                                                                                                       
     VALUE _IMPRACE                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White, Non-Hispanic"                                                                                                                                          
           2                   =    "Black, Non-Hispanic"                                                                                                                                          
           3                   =    "Asian, Non-Hispanic"                                                                                                                                          
           4                   =    "American Indian/Alaskan Native, Non-Hispanic"                                                                                                                 
           5                   =    "Hispanic"                                                                                                                                                     
           6                   =    "Other race, Non-Hispanic"                                                                                                                                     
           ;                                                                                                                                                                                       
     VALUE _IMPSEX                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Male"                                                                                                                                                         
           2                   =    "Female"                                                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _INCOMG                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Less than $15,000"                                                                                                                                            
           2                   =    "$15,000 to less than $25,000"                                                                                                                                 
           3                   =    "$25,000 to less than $35,000"                                                                                                                                 
           4                   =    "$35,000 to less than $50,000"                                                                                                                                 
           5                   =    "$50,000 or more"                                                                                                                                              
           9                   =    "Dont know/Not sure/Missing"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _M1RACE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White only"                                                                                                                                                   
           2                   =    "Black or African American only"                                                                                                                               
           3                   =    "American Indian or Alaskan Native only"                                                                                                                       
           4                   =    "Asian Only"                                                                                                                                                   
           5                   =    "Native Hawaiian or other Pacific Islander only"                                                                                                               
           6                   =    "Other race only"                                                                                                                                              
           7                   =    "Multiracial"                                                                                                                                                  
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _MENT14D                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Zero days when mental health not good"                                                                                                                        
           2                   =    "1-13 days when mental health not good"                                                                                                                        
           3                   =    "14+ days when mental health not good"                                                                                                                         
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _METSTAT                                                                                                                                                                                
           .                   =    "Not defined or Missing"                                                                                                                                       
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Metropolitan counties (_URBNRRL = 1,2,3,4)"                                                                                                                   
           2                   =    "Nonmetropolitan counties (_URBNRRL = 5,6)"                                                                                                                    
           ;                                                                                                                                                                                       
     VALUE _MICHD                                                                                                                                                                                  
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Reported having MI or CHD"                                                                                                                                    
           2                   =    "Did not report having MI or CHD"                                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _M_RACE                                                                                                                                                                                 
           .                   =    "Not asked or Missing"                                                                                                                                         
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           10                  =    "White"                                                                                                                                                        
           20                  =    "Black or African American"                                                                                                                                    
           30                  =    "American Indian or Alaska Native"                                                                                                                             
           40                  =    "Asian"                                                                                                                                                        
           41                  =    "Asian Indian"                                                                                                                                                 
           42                  =    "Chinese"                                                                                                                                                      
           43                  =    "Filipino"                                                                                                                                                     
           44                  =    "Japanese"                                                                                                                                                     
           45                  =    "Korean"                                                                                                                                                       
           46                  =    "Vietnamese"                                                                                                                                                   
           47                  =    "Other Asian"                                                                                                                                                  
           50                  =    "Pacific Islander"                                                                                                                                             
           51                  =    "Native Hawaiian"                                                                                                                                              
           52                  =    "Guamanian or Chamorro"                                                                                                                                        
           53                  =    "Samoan"                                                                                                                                                       
           54                  =    "Other Pacific Islander"                                                                                                                                       
           60                  =    "Other"                                                                                                                                                        
           70                  =    "Multiple responses"                                                                                                                                           
           77                  =    "Dont know/Not Sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _P1RACE                                                                                                                                                                                 
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White"                                                                                                                                                        
           2                   =    "Black or African American"                                                                                                                                    
           3                   =    "American Indian or Alaskan Native"                                                                                                                            
           4                   =    "Asian"                                                                                                                                                        
           5                   =    "Native Hawaiian or other Pacific Islander"                                                                                                                    
           6                   =    "Other race"                                                                                                                                                   
           7                   =    "No preferred race"                                                                                                                                            
           8                   =    "Multiracial but preferred race not answered"                                                                                                                  
           77                  =    "Dont know/Not sure"                                                                                                                                          
           99                  =    "Refused"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _PHYS14D                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Zero days when physical health not good"                                                                                                                      
           2                   =    "1-13 days when physical health not good"                                                                                                                      
           3                   =    "14+ days when physical health not good"                                                                                                                       
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _RACE                                                                                                                                                                                   
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White only, non-Hispanic"                                                                                                                                     
           2                   =    "Black only, non-Hispanic"                                                                                                                                     
           3                   =    "American Indian or Alaskan Native only, Non-Hispanic"                                                                                                         
           4                   =    "Asian only, non-Hispanic"                                                                                                                                     
           5                   =    "Native Hawaiian or other Pacific Islander only, Non-Hispanic"                                                                                                 
           6                   =    "Other race only, non-Hispanic"                                                                                                                                
           7                   =    "Multiracial, non-Hispanic"                                                                                                                                    
           8                   =    "Hispanic"                                                                                                                                                     
           9                   =    "Dont know/Not sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _RACE1_G                                                                                                                                                                                
           .                   =    "Dont know/Not sure/Refused component question"                                                                                                               
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "White - Non-Hispanic"                                                                                                                                         
           2                   =    "Black - Non-Hispanic"                                                                                                                                         
           3                   =    "Hispanic"                                                                                                                                                     
           4                   =    "Other race only, Non-Hispanic"                                                                                                                                
           5                   =    "Multiracial, Non-Hispanic"                                                                                                                                    
           ;                                                                                                                                                                                       
     VALUE _RF22PSA                                                                                                                                                                                
           .                   =    "Missing or Age less than 40 or Female"                                                                                                                        
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Yes"                                                                                                                                                          
           2                   =    "No"                                                                                                                                                           
           9                   =    "Dont know/Not Sure/Refused"                                                                                                                                  
           ;                                                                                                                                                                                       
     VALUE _RF3BLDS                                                                                                                                                                                
           .                   =    "Missing, Age less than 50, Age greater than 75"                                                                                                               
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Had a blood stool test in the past year"                                                                                                                      
           2                   =    "Hve not had a blood stool test in the past year"                                                                                                              
           ;                                                                                                                                                                                       
     VALUE _RFHLTH                                                                                                                                                                                 
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Good or Better Health"                                                                                                                                        
           2                   =    "Fair or Poor Health"                                                                                                                                          
           9                   =    "Dont know/Not Sure Or Refused/Missing"                                                                                                                       
           ;                                                                                                                                                                                       
     VALUE _STATE                                                                                                                                                                                  
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Alabama"                                                                                                                                                      
           2                   =    "Alaska"                                                                                                                                                       
           4                   =    "Arizona"                                                                                                                                                      
           5                   =    "Arkansas"                                                                                                                                                     
           6                   =    "California"                                                                                                                                                   
           8                   =    "Colorado"                                                                                                                                                     
           9                   =    "Connecticut"                                                                                                                                                  
           10                  =    "Delaware"                                                                                                                                                     
           11                  =    "District of Columbia"                                                                                                                                         
           12                  =    "Florida"                                                                                                                                                      
           13                  =    "Georgia"                                                                                                                                                      
           15                  =    "Hawaii"                                                                                                                                                       
           16                  =    "Idaho"                                                                                                                                                        
           17                  =    "Illinois"                                                                                                                                                     
           18                  =    "Indiana"                                                                                                                                                      
           19                  =    "Iowa"                                                                                                                                                         
           20                  =    "Kansas"                                                                                                                                                       
           21                  =    "Kentucky"                                                                                                                                                     
           22                  =    "Louisiana"                                                                                                                                                    
           23                  =    "Maine"                                                                                                                                                        
           24                  =    "Maryland"                                                                                                                                                     
           25                  =    "Massachusetts"                                                                                                                                                
           26                  =    "Michigan"                                                                                                                                                     
           27                  =    "Minnesota"                                                                                                                                                    
           28                  =    "Mississippi"                                                                                                                                                  
           29                  =    "Missouri"                                                                                                                                                     
           30                  =    "Montana"                                                                                                                                                      
           31                  =    "Nebraska"                                                                                                                                                     
           32                  =    "Nevada"                                                                                                                                                       
           33                  =    "New Hampshire"                                                                                                                                                
           34                  =    "New Jersey"                                                                                                                                                   
           35                  =    "New Mexico"                                                                                                                                                   
           36                  =    "New York"                                                                                                                                                     
           37                  =    "North Carolina"                                                                                                                                               
           38                  =    "North Dakota"                                                                                                                                                 
           39                  =    "Ohio"                                                                                                                                                         
           40                  =    "Oklahoma"                                                                                                                                                     
           41                  =    "Oregon"                                                                                                                                                       
           42                  =    "Pennsylvania"                                                                                                                                                 
           44                  =    "Rhode Island"                                                                                                                                                 
           45                  =    "South Carolina"                                                                                                                                               
           46                  =    "South Dakota"                                                                                                                                                 
           47                  =    "Tennessee"                                                                                                                                                    
           48                  =    "Texas"                                                                                                                                                        
           49                  =    "Utah"                                                                                                                                                         
           50                  =    "Vermont"                                                                                                                                                      
           51                  =    "Virginia"                                                                                                                                                     
           53                  =    "Washington"                                                                                                                                                   
           54                  =    "West Virginia"                                                                                                                                                
           55                  =    "Wisconsin"                                                                                                                                                    
           56                  =    "Wyoming"                                                                                                                                                      
           66                  =    "Guam"                                                                                                                                                         
           72                  =    "Puerto Rico"                                                                                                                                                  
           78                  =    "Virgin Islands"                                                                                                                                               
           ;                                                                                                                                                                                       
     VALUE _TOTINDA                                                                                                                                                                                
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Had physical activity or exercise"                                                                                                                            
           2                   =    "No physical activity or exercise in last 30 days"                                                                                                             
           9                   =    "Dont know/Refused/Missing"                                                                                                                                   
           ;                                                                                                                                                                                       
     VALUE _URBNRRL                                                                                                                                                                                
           .                   =    "Missing"                                                                                                                                                      
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Large central metro"                                                                                                                                          
           2                   =    "Large fringe metro"                                                                                                                                           
           3                   =    "Medium metro"                                                                                                                                                 
           4                   =    "Small metro"                                                                                                                                                  
           5                   =    "Micropolitan"                                                                                                                                                 
           6                   =    "Noncore"                                                                                                                                                      
           ;                                                                                                                                                                                       
     VALUE _URBSTAT                                                                                                                                                                                
           .                   =    "Not defined or Missing"                                                                                                                                       
           .D                  =    "DK/NS"                                                                                                                                                        
           .R                  =    "REFUSED"                                                                                                                                                      
           1                   =    "Urban counties (_URBNRRL = 1,2,3,4,5)"                                                                                                                        
           2                   =    "Rural counties (_URBNRRL = 6)"                                                                                                                                
           ;                                                                                                                                                                                       
     VALUE $IMONTH                                                                                                                                                                                 
           "1"                 =    "January"                                                                                                                                                      
           "10"                =    "October"                                                                                                                                                      
           "11"                =    "November"                                                                                                                                                     
           "12"                =    "December"                                                                                                                                                     
           "2"                 =    "February"                                                                                                                                                     
           "3"                 =    "March"                                                                                                                                                        
           "4"                 =    "April"                                                                                                                                                        
           "5"                 =    "May"                                                                                                                                                          
           "6"                 =    "June"                                                                                                                                                         
           "7"                 =    "July"                                                                                                                                                         
           "8"                 =    "August"                                                                                                                                                       
           "9"                 =    "September"                                                                                                                                                    
           ;                                                                                                                                                                                                                                           


RUN;
